@@ -50,6 +50,12 @@ mock_lambda = lazy_load(
     ".awslambda", "mock_lambda", boto3_name="lambda", backend="lambda_backends"
 )
 mock_batch = lazy_load(".batch", "mock_batch")
+mock_batch_simple = lazy_load(
+    ".batch_simple",
+    "mock_batch_simple",
+    boto3_name="batch",
+    backend="batch_simple_backends",
+)
 mock_budgets = lazy_load(".budgets", "mock_budgets")
 mock_cloudformation = lazy_load(".cloudformation", "mock_cloudformation")
 mock_cloudfront = lazy_load(".cloudfront", "mock_cloudfront")
@@ -199,7 +205,7 @@ mock_all = MockAll
 # logging.getLogger('boto').setLevel(logging.CRITICAL)
 
 __title__ = "moto"
-__version__ = "3.1.7"
+__version__ = "3.1.8"
 
 
 try:
