@@ -1,4 +1,4 @@
-from moto.core import BaseBackend, BaseModel
+from moto.core import ACCOUNT_ID, BaseBackend, BaseModel
 from moto.core.utils import BackendDict
 from moto.ecs import ecs_backends
 from .exceptions import AWSValidationException
@@ -65,6 +65,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
         self.ecs_backend = ecs_backends[region]
         self.targets = OrderedDict()
         self.policies = {}
+        self.scheduled_actions = list()
 
     def reset(self):
         region = self.region
@@ -82,9 +83,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
     def applicationautoscaling_backend(self):
         return applicationautoscaling_backends[self.region]
 
-    def describe_scalable_targets(
-        self, namespace, r_ids=None, dimension=None,
-    ):
+    def describe_scalable_targets(self, namespace, r_ids=None, dimension=None):
         """Describe scalable targets."""
         if r_ids is None:
             r_ids = []
@@ -231,6 +230,87 @@ class ApplicationAutoscalingBackend(BaseBackend):
                 )
             )
 
+    def delete_scheduled_action(
+        self, service_namespace, scheduled_action_name, resource_id, scalable_dimension
+    ):
+        self.scheduled_actions = [
+            a
+            for a in self.scheduled_actions
+            if not (
+                a.service_namespace == service_namespace
+                and a.scheduled_action_name == scheduled_action_name
+                and a.resource_id == resource_id
+                and a.scalable_dimension == scalable_dimension
+            )
+        ]
+
+    def describe_scheduled_actions(
+        self, scheduled_action_names, service_namespace, resource_id, scalable_dimension
+    ):
+        """
+        Pagination is not yet implemented
+        """
+        result = [
+            a
+            for a in self.scheduled_actions
+            if a.service_namespace == service_namespace
+        ]
+        if scheduled_action_names:
+            result = [
+                a for a in result if a.scheduled_action_name in scheduled_action_names
+            ]
+        if resource_id:
+            result = [a for a in result if a.resource_id == resource_id]
+        if scalable_dimension:
+            result = [a for a in result if a.scalable_dimension == scalable_dimension]
+        return result
+
+    def put_scheduled_action(
+        self,
+        service_namespace,
+        schedule,
+        timezone,
+        scheduled_action_name,
+        resource_id,
+        scalable_dimension,
+        start_time,
+        end_time,
+        scalable_target_action,
+    ):
+        existing_action = next(
+            (
+                a
+                for a in self.scheduled_actions
+                if a.service_namespace == service_namespace
+                and a.resource_id == resource_id
+                and a.scalable_dimension == scalable_dimension
+            ),
+            None,
+        )
+        if existing_action:
+            existing_action.update(
+                schedule,
+                timezone,
+                scheduled_action_name,
+                start_time,
+                end_time,
+                scalable_target_action,
+            )
+        else:
+            action = FakeScheduledAction(
+                service_namespace,
+                schedule,
+                timezone,
+                scheduled_action_name,
+                resource_id,
+                scalable_dimension,
+                start_time,
+                end_time,
+                scalable_target_action,
+                self.region,
+            )
+            self.scheduled_actions.append(action)
+
 
 def _target_params_are_valid(namespace, r_id, dimension):
     """Check whether namespace, resource_id and dimension are valid and consistent with each other."""
@@ -356,4 +436,51 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
         )
 
 
+class FakeScheduledAction(BaseModel):
+    def __init__(
+        self,
+        service_namespace,
+        schedule,
+        timezone,
+        scheduled_action_name,
+        resource_id,
+        scalable_dimension,
+        start_time,
+        end_time,
+        scalable_target_action,
+        region,
+    ):
+        self.arn = f"arn:aws:autoscaling:{region}:{ACCOUNT_ID}:scheduledAction:{service_namespace}:scheduledActionName/{scheduled_action_name}"
+        self.service_namespace = service_namespace
+        self.schedule = schedule
+        self.timezone = timezone
+        self.scheduled_action_name = scheduled_action_name
+        self.resource_id = resource_id
+        self.scalable_dimension = scalable_dimension
+        self.start_time = start_time
+        self.end_time = end_time
+        self.scalable_target_action = scalable_target_action
+        self.creation_time = time.time()
+
+    def update(
+        self,
+        schedule,
+        timezone,
+        scheduled_action_name,
+        start_time,
+        end_time,
+        scalable_target_action,
+    ):
+        if scheduled_action_name:
+            self.scheduled_action_name = scheduled_action_name
+        if schedule:
+            self.schedule = schedule
+        if timezone:
+            self.timezone = timezone
+        if scalable_target_action:
+            self.scalable_target_action = scalable_target_action
+        self.start_time = start_time
+        self.end_time = end_time
+
+
 applicationautoscaling_backends = BackendDict(ApplicationAutoscalingBackend, "ec2")
