@@ -4,7 +4,7 @@ from werkzeug.exceptions import BadRequest
 
 class AthenaClientError(BadRequest):
     def __init__(self, code, message):
-        super(AthenaClientError, self).__init__()
+        super().__init__()
         self.description = json.dumps(
             {
                 "Error": {
