@@ -46,9 +46,7 @@ class InstanceState(object):
 
 
 class FakeLifeCycleHook(BaseModel):
-    def __init__(
-        self, name, as_name, transition, timeout, result,
-    ):
+    def __init__(self, name, as_name, transition, timeout, result):
         self.name = name
         self.as_name = as_name
         if transition:
@@ -68,18 +66,24 @@ class FakeScalingPolicy(BaseModel):
         self,
         name,
         policy_type,
+        metric_aggregation_type,
         adjustment_type,
         as_name,
+        min_adjustment_magnitude,
         scaling_adjustment,
         cooldown,
         target_tracking_config,
         step_adjustments,
+        estimated_instance_warmup,
+        predictive_scaling_configuration,
         autoscaling_backend,
     ):
         self.name = name
         self.policy_type = policy_type
+        self.metric_aggregation_type = metric_aggregation_type
         self.adjustment_type = adjustment_type
         self.as_name = as_name
+        self.min_adjustment_magnitude = min_adjustment_magnitude
         self.scaling_adjustment = scaling_adjustment
         if cooldown is not None:
             self.cooldown = cooldown
@@ -87,6 +91,8 @@ class FakeScalingPolicy(BaseModel):
             self.cooldown = DEFAULT_COOLDOWN
         self.target_tracking_config = target_tracking_config
         self.step_adjustments = step_adjustments
+        self.estimated_instance_warmup = estimated_instance_warmup
+        self.predictive_scaling_configuration = predictive_scaling_configuration
         self.autoscaling_backend = autoscaling_backend
 
     @property
@@ -125,6 +131,10 @@ class FakeLaunchConfiguration(CloudFormationModel):
         ebs_optimized,
         associate_public_ip_address,
         block_device_mapping_dict,
+        region_name,
+        metadata_options,
+        classic_link_vpc_id,
+        classic_link_vpc_security_groups,
     ):
         self.name = name
         self.image_id = image_id
@@ -140,6 +150,10 @@ class FakeLaunchConfiguration(CloudFormationModel):
         self.ebs_optimized = ebs_optimized
         self.associate_public_ip_address = associate_public_ip_address
         self.block_device_mapping_dict = block_device_mapping_dict
+        self.metadata_options = metadata_options
+        self.classic_link_vpc_id = classic_link_vpc_id
+        self.classic_link_vpc_security_groups = classic_link_vpc_security_groups
+        self.arn = f"arn:aws:autoscaling:{region_name}:{ACCOUNT_ID}:launchConfiguration:9dbbbf87-6141-428a-a409-0752edbe6cad:launchConfigurationName/{self.name}"
 
     @classmethod
     def create_from_instance(cls, name, instance, backend):
@@ -157,7 +171,8 @@ class FakeLaunchConfiguration(CloudFormationModel):
             spot_price=None,
             ebs_optimized=instance.ebs_optimized,
             associate_public_ip_address=instance.associate_public_ip,
-            block_device_mappings=instance.block_device_mapping,
+            # We expect a dictionary in the same format as when the user calls it
+            block_device_mappings=instance.block_device_mapping.to_source_dict(),
         )
         return config
 
@@ -243,17 +258,20 @@ class FakeLaunchConfiguration(CloudFormationModel):
         block_device_map = BlockDeviceMapping()
         for mapping in self.block_device_mapping_dict:
             block_type = BlockDeviceType()
-            mount_point = mapping.get("device_name")
-            if "ephemeral" in mapping.get("virtual_name", ""):
-                block_type.ephemeral_name = mapping.get("virtual_name")
+            mount_point = mapping.get("DeviceName")
+            if mapping.get("VirtualName") and "ephemeral" in mapping.get("VirtualName"):
+                block_type.ephemeral_name = mapping.get("VirtualName")
+            elif mapping.get("NoDevice", "false") == "true":
+                block_type.no_device = "true"
             else:
-                block_type.volume_type = mapping.get("ebs._volume_type")
-                block_type.snapshot_id = mapping.get("ebs._snapshot_id")
-                block_type.delete_on_termination = mapping.get(
-                    "ebs._delete_on_termination"
-                )
-                block_type.size = mapping.get("ebs._volume_size")
-                block_type.iops = mapping.get("ebs._iops")
+                ebs = mapping.get("Ebs", {})
+                block_type.volume_type = ebs.get("VolumeType")
+                block_type.snapshot_id = ebs.get("SnapshotId")
+                block_type.delete_on_termination = ebs.get("DeleteOnTermination")
+                block_type.size = ebs.get("VolumeSize")
+                block_type.iops = ebs.get("Iops")
+                block_type.throughput = ebs.get("Throughput")
+                block_type.encrypted = ebs.get("Encrypted")
             block_device_map[mount_point] = block_type
         return block_device_map
 
@@ -392,7 +410,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
                 self.launch_template = self.ec2_backend.get_launch_template_by_name(
                     launch_template_name
                 )
-            self.launch_template_version = int(launch_template["version"])
+            self.launch_template_version = launch_template["version"]
 
     @staticmethod
     def __set_string_propagate_at_launch_booleans_on_tags(tags):
@@ -523,11 +541,8 @@ class FakeAutoScalingGroup(CloudFormationModel):
         launch_config_name,
         launch_template,
         vpc_zone_identifier,
-        default_cooldown,
         health_check_period,
         health_check_type,
-        placement_group,
-        termination_policies,
         new_instances_protected_from_scale_in=None,
     ):
         self._set_azs_and_vpcs(availability_zones, vpc_zone_identifier, update=True)
@@ -617,6 +632,7 @@ class FakeAutoScalingGroup(CloudFormationModel):
             instance_type=self.instance_type,
             tags={"instance": propagated_tags},
             placement=random.choice(self.availability_zones),
+            launch_config=self.launch_config,
         )
         for instance in reservation.instances:
             instance.autoscaling_group = self
@@ -674,6 +690,9 @@ class AutoScalingBackend(BaseBackend):
         associate_public_ip_address,
         block_device_mappings,
         instance_id=None,
+        metadata_options=None,
+        classic_link_vpc_id=None,
+        classic_link_vpc_security_groups=None,
     ):
         valid_requests = [
             instance_id is not None,
@@ -701,6 +720,10 @@ class AutoScalingBackend(BaseBackend):
             ebs_optimized=ebs_optimized,
             associate_public_ip_address=associate_public_ip_address,
             block_device_mapping_dict=block_device_mappings,
+            region_name=self.region,
+            metadata_options=metadata_options,
+            classic_link_vpc_id=classic_link_vpc_id,
+            classic_link_vpc_security_groups=classic_link_vpc_security_groups,
         )
         self.launch_configurations[name] = launch_configuration
         return launch_configuration
@@ -810,13 +833,13 @@ class AutoScalingBackend(BaseBackend):
         launch_config_name,
         launch_template,
         vpc_zone_identifier,
-        default_cooldown,
         health_check_period,
         health_check_type,
-        placement_group,
-        termination_policies,
         new_instances_protected_from_scale_in=None,
     ):
+        """
+        The parameter DefaultCooldown, PlacementGroup, TerminationPolicies are not yet implemented
+        """
         # TODO: Add MixedInstancesPolicy once implemented.
         # Verify only a single launch config-like parameter is provided.
         if launch_config_name and launch_template:
@@ -834,11 +857,8 @@ class AutoScalingBackend(BaseBackend):
             launch_config_name=launch_config_name,
             launch_template=launch_template,
             vpc_zone_identifier=vpc_zone_identifier,
-            default_cooldown=default_cooldown,
             health_check_period=health_check_period,
             health_check_type=health_check_type,
-            placement_group=placement_group,
-            termination_policies=termination_policies,
             new_instances_protected_from_scale_in=new_instances_protected_from_scale_in,
         )
         return group
@@ -890,9 +910,10 @@ class AutoScalingBackend(BaseBackend):
             self.update_attached_elbs(group.name)
             self.update_attached_target_groups(group.name)
 
-    def set_instance_health(
-        self, instance_id, health_status, should_respect_grace_period
-    ):
+    def set_instance_health(self, instance_id, health_status):
+        """
+        The ShouldRespectGracePeriod-parameter is not yet implemented
+        """
         instance = self.ec2_backend.get_instance(instance_id)
         instance_state = next(
             instance_state
@@ -952,7 +973,7 @@ class AutoScalingBackend(BaseBackend):
         self.set_desired_capacity(group_name, desired_capacity)
 
     def create_lifecycle_hook(self, name, as_name, transition, timeout, result):
-        lifecycle_hook = FakeLifeCycleHook(name, as_name, transition, timeout, result,)
+        lifecycle_hook = FakeLifeCycleHook(name, as_name, transition, timeout, result)
 
         self.lifecycle_hooks["%s_%s" % (as_name, name)] = lifecycle_hook
         return lifecycle_hook
@@ -970,27 +991,35 @@ class AutoScalingBackend(BaseBackend):
     def delete_lifecycle_hook(self, as_name, name):
         self.lifecycle_hooks.pop("%s_%s" % (as_name, name), None)
 
-    def create_autoscaling_policy(
+    def put_scaling_policy(
         self,
         name,
         policy_type,
+        metric_aggregation_type,
         adjustment_type,
         as_name,
+        min_adjustment_magnitude,
         scaling_adjustment,
         cooldown,
         target_tracking_config,
         step_adjustments,
+        estimated_instance_warmup,
+        predictive_scaling_configuration,
     ):
         policy = FakeScalingPolicy(
             name,
             policy_type,
-            adjustment_type,
-            as_name,
-            scaling_adjustment,
-            cooldown,
-            target_tracking_config,
-            step_adjustments,
-            self,
+            metric_aggregation_type,
+            adjustment_type=adjustment_type,
+            as_name=as_name,
+            min_adjustment_magnitude=min_adjustment_magnitude,
+            scaling_adjustment=scaling_adjustment,
+            cooldown=cooldown,
+            target_tracking_config=target_tracking_config,
+            step_adjustments=step_adjustments,
+            estimated_instance_warmup=estimated_instance_warmup,
+            predictive_scaling_configuration=predictive_scaling_configuration,
+            autoscaling_backend=self,
         )
 
         self.policies[name] = policy
@@ -1033,10 +1062,10 @@ class AutoScalingBackend(BaseBackend):
         for elb in elbs:
             elb_instace_ids = set(elb.instance_ids)
             self.elb_backend.register_instances(
-                elb.name, group_instance_ids - elb_instace_ids, from_autoscaling=True,
+                elb.name, group_instance_ids - elb_instace_ids, from_autoscaling=True
             )
             self.elb_backend.deregister_instances(
-                elb.name, elb_instace_ids - group_instance_ids, from_autoscaling=True,
+                elb.name, elb_instace_ids - group_instance_ids, from_autoscaling=True
             )
 
     def update_attached_target_groups(self, group_name):
