@@ -7,7 +7,7 @@ import string
 from moto.core import ACCOUNT_ID
 
 
-def generate_stack_id(stack_name, region="us-east-1", account="123456789"):
+def generate_stack_id(stack_name, region="us-east-1", account=ACCOUNT_ID):
     random_id = uuid.uuid4()
     return "arn:aws:cloudformation:{}:{}:stack/{}/{}".format(
         region, account, stack_name, random_id
@@ -16,8 +16,8 @@ def generate_stack_id(stack_name, region="us-east-1", account="123456789"):
 
 def generate_changeset_id(changeset_name, region_name):
     random_id = uuid.uuid4()
-    return "arn:aws:cloudformation:{0}:123456789:changeSet/{1}/{2}".format(
-        region_name, changeset_name, random_id
+    return "arn:aws:cloudformation:{0}:{1}:changeSet/{2}/{3}".format(
+        region_name, ACCOUNT_ID, changeset_name, random_id
     )
 
 
