@@ -4,6 +4,7 @@ import time
 from datetime import datetime
 from moto.core import ACCOUNT_ID, BaseBackend, BaseModel
 from moto.core.utils import iso_8601_datetime_without_milliseconds, BackendDict
+from moto.utilities.tagging_service import TaggingService
 from .exceptions import (
     S3BucketDoesNotExistException,
     InsufficientSnsTopicPolicyException,
@@ -78,9 +79,13 @@ class Trail(BaseModel):
         bucket_name,
         s3_key_prefix,
         sns_topic_name,
+        is_global,
         is_multi_region,
         log_validation,
         is_org_trail,
+        cw_log_group_arn,
+        cw_role_arn,
+        kms_key_id,
     ):
         self.region_name = region_name
         self.trail_name = trail_name
@@ -90,10 +95,17 @@ class Trail(BaseModel):
         self.is_multi_region = is_multi_region
         self.log_validation = log_validation
         self.is_org_trail = is_org_trail
+        self.include_global_service_events = is_global
+        self.cw_log_group_arn = cw_log_group_arn
+        self.cw_role_arn = cw_role_arn
+        self.kms_key_id = kms_key_id
         self.check_name()
         self.check_bucket_exists()
         self.check_topic_exists()
         self.status = TrailStatus()
+        self.event_selectors = list()
+        self.advanced_event_selectors = list()
+        self.insight_selectors = list()
 
     @property
     def arn(self):
@@ -145,6 +157,56 @@ class Trail(BaseModel):
     def stop_logging(self):
         self.status.stop_logging()
 
+    def put_event_selectors(self, event_selectors, advanced_event_selectors):
+        if event_selectors:
+            self.event_selectors = event_selectors
+        elif advanced_event_selectors:
+            self.event_selectors = []
+            self.advanced_event_selectors = advanced_event_selectors
+
+    def get_event_selectors(self):
+        return self.event_selectors, self.advanced_event_selectors
+
+    def put_insight_selectors(self, insight_selectors):
+        self.insight_selectors.extend(insight_selectors)
+
+    def get_insight_selectors(self):
+        return self.insight_selectors
+
+    def update(
+        self,
+        s3_bucket_name,
+        s3_key_prefix,
+        sns_topic_name,
+        include_global_service_events,
+        is_multi_region_trail,
+        enable_log_file_validation,
+        is_organization_trail,
+        cw_log_group_arn,
+        cw_role_arn,
+        kms_key_id,
+    ):
+        if s3_bucket_name is not None:
+            self.bucket_name = s3_bucket_name
+        if s3_key_prefix is not None:
+            self.s3_key_prefix = s3_key_prefix
+        if sns_topic_name is not None:
+            self.sns_topic_name = sns_topic_name
+        if include_global_service_events is not None:
+            self.include_global_service_events = include_global_service_events
+        if is_multi_region_trail is not None:
+            self.is_multi_region = is_multi_region_trail
+        if enable_log_file_validation is not None:
+            self.log_validation = enable_log_file_validation
+        if is_organization_trail is not None:
+            self.is_org_trail = is_organization_trail
+        if cw_log_group_arn is not None:
+            self.cw_log_group_arn = cw_log_group_arn
+        if cw_role_arn is not None:
+            self.cw_role_arn = cw_role_arn
+        if kms_key_id is not None:
+            self.kms_key_id = kms_key_id
+
     def short(self):
         return {
             "Name": self.trail_name,
@@ -156,13 +218,16 @@ class Trail(BaseModel):
         desc = {
             "Name": self.trail_name,
             "S3BucketName": self.bucket_name,
-            "IncludeGlobalServiceEvents": True,
+            "IncludeGlobalServiceEvents": self.include_global_service_events,
             "IsMultiRegionTrail": self.is_multi_region,
             "TrailARN": self.arn,
             "LogFileValidationEnabled": self.log_validation,
             "IsOrganizationTrail": self.is_org_trail,
             "HasCustomEventSelectors": False,
             "HasInsightSelectors": False,
+            "CloudWatchLogsLogGroupArn": self.cw_log_group_arn,
+            "CloudWatchLogsRoleArn": self.cw_role_arn,
+            "KmsKeyId": self.kms_key_id,
         }
         if self.s3_key_prefix is not None:
             desc["S3KeyPrefix"] = self.s3_key_prefix
@@ -180,6 +245,7 @@ class CloudTrailBackend(BaseBackend):
     def __init__(self, region_name):
         self.region_name = region_name
         self.trails = dict()
+        self.tagging_service = TaggingService(tag_name="TagsList")
 
     def create_trail(
         self,
@@ -187,9 +253,14 @@ class CloudTrailBackend(BaseBackend):
         bucket_name,
         s3_key_prefix,
         sns_topic_name,
+        is_global,
         is_multi_region,
         log_validation,
         is_org_trail,
+        cw_log_group_arn,
+        cw_role_arn,
+        kms_key_id,
+        tags_list,
     ):
         trail = Trail(
             self.region_name,
@@ -197,19 +268,27 @@ class CloudTrailBackend(BaseBackend):
             bucket_name,
             s3_key_prefix,
             sns_topic_name,
+            is_global,
             is_multi_region,
             log_validation,
             is_org_trail,
+            cw_log_group_arn,
+            cw_role_arn,
+            kms_key_id,
         )
         self.trails[name] = trail
+        self.tagging_service.tag_resource(trail.arn, tags_list)
         return trail
 
-    def get_trail(self, name):
-        if len(name) < 3:
-            raise TrailNameTooShort(actual_length=len(name))
-        if name not in self.trails:
-            raise TrailNotFoundException(name)
-        return self.trails[name]
+    def get_trail(self, name_or_arn):
+        if len(name_or_arn) < 3:
+            raise TrailNameTooShort(actual_length=len(name_or_arn))
+        if name_or_arn in self.trails:
+            return self.trails[name_or_arn]
+        for trail in self.trails.values():
+            if trail.arn == name_or_arn:
+                return trail
+        raise TrailNotFoundException(name_or_arn)
 
     def get_trail_status(self, name):
         if len(name) < 3:
@@ -253,11 +332,79 @@ class CloudTrailBackend(BaseBackend):
         if name in self.trails:
             del self.trails[name]
 
+    def update_trail(
+        self,
+        name,
+        s3_bucket_name,
+        s3_key_prefix,
+        sns_topic_name,
+        include_global_service_events,
+        is_multi_region_trail,
+        enable_log_file_validation,
+        is_organization_trail,
+        cw_log_group_arn,
+        cw_role_arn,
+        kms_key_id,
+    ):
+        trail = self.get_trail(name_or_arn=name)
+        trail.update(
+            s3_bucket_name=s3_bucket_name,
+            s3_key_prefix=s3_key_prefix,
+            sns_topic_name=sns_topic_name,
+            include_global_service_events=include_global_service_events,
+            is_multi_region_trail=is_multi_region_trail,
+            enable_log_file_validation=enable_log_file_validation,
+            is_organization_trail=is_organization_trail,
+            cw_log_group_arn=cw_log_group_arn,
+            cw_role_arn=cw_role_arn,
+            kms_key_id=kms_key_id,
+        )
+        return trail
+
     def reset(self):
         """Re-initialize all attributes for this instance."""
         region_name = self.region_name
         self.__dict__ = {}
         self.__init__(region_name)
 
+    def put_event_selectors(
+        self, trail_name, event_selectors, advanced_event_selectors
+    ):
+        trail = self.get_trail(trail_name)
+        trail.put_event_selectors(event_selectors, advanced_event_selectors)
+        trail_arn = trail.arn
+        return trail_arn, event_selectors, advanced_event_selectors
+
+    def get_event_selectors(self, trail_name):
+        trail = self.get_trail(trail_name)
+        event_selectors, advanced_event_selectors = trail.get_event_selectors()
+        return trail.arn, event_selectors, advanced_event_selectors
+
+    def add_tags(self, resource_id, tags_list):
+        self.tagging_service.tag_resource(resource_id, tags_list)
+
+    def remove_tags(self, resource_id, tags_list):
+        self.tagging_service.untag_resource_using_tags(resource_id, tags_list)
+
+    def list_tags(self, resource_id_list):
+        """
+        Pagination is not yet implemented
+        """
+        resp = [{"ResourceId": r_id} for r_id in resource_id_list]
+        for item in resp:
+            item["TagsList"] = self.tagging_service.list_tags_for_resource(
+                item["ResourceId"]
+            )["TagsList"]
+        return resp
+
+    def put_insight_selectors(self, trail_name, insight_selectors):
+        trail = self.get_trail(trail_name)
+        trail.put_insight_selectors(insight_selectors)
+        return trail.arn, insight_selectors
+
+    def get_insight_selectors(self, trail_name):
+        trail = self.get_trail(trail_name)
+        return trail.arn, trail.get_insight_selectors()
+
 
 cloudtrail_backends = BackendDict(CloudTrailBackend, "cloudtrail")
