@@ -5,7 +5,7 @@ class RepositoryNameExistsException(JsonRESTError):
     code = 400
 
     def __init__(self, repository_name):
-        super(RepositoryNameExistsException, self).__init__(
+        super().__init__(
             "RepositoryNameExistsException",
             "Repository named {0} already exists".format(repository_name),
         )
@@ -15,7 +15,7 @@ class RepositoryDoesNotExistException(JsonRESTError):
     code = 400
 
     def __init__(self, repository_name):
-        super(RepositoryDoesNotExistException, self).__init__(
+        super().__init__(
             "RepositoryDoesNotExistException",
             "{0} does not exist".format(repository_name),
         )
@@ -25,7 +25,7 @@ class InvalidRepositoryNameException(JsonRESTError):
     code = 400
 
     def __init__(self):
-        super(InvalidRepositoryNameException, self).__init__(
+        super().__init__(
             "InvalidRepositoryNameException",
             "The repository name is not valid. Repository names can be any valid "
             "combination of letters, numbers, "
