@@ -69,6 +69,12 @@ class CodePipeline(BaseModel):
 class CodePipelineBackend(BaseBackend):
     def __init__(self, region=None):
         self.pipelines = {}
+        self.region = region
+
+    def reset(self):
+        region_name = self.region
+        self.__dict__ = {}
+        self.__init__(region_name)
 
     @staticmethod
     def default_vpc_endpoint_service(service_region, zones):
@@ -81,7 +87,7 @@ class CodePipelineBackend(BaseBackend):
     def iam_backend(self):
         return iam_backends["global"]
 
-    def create_pipeline(self, region, pipeline, tags):
+    def create_pipeline(self, pipeline, tags):
         if pipeline["name"] in self.pipelines:
             raise InvalidStructureException(
                 "A pipeline with the name '{0}' already exists in account '{1}'".format(
@@ -108,7 +114,7 @@ class CodePipelineBackend(BaseBackend):
                 "Pipeline has only 1 stage(s). There should be a minimum of 2 stages in a pipeline"
             )
 
-        self.pipelines[pipeline["name"]] = CodePipeline(region, pipeline)
+        self.pipelines[pipeline["name"]] = CodePipeline(self.region, pipeline)
 
         if tags:
             self.pipelines[pipeline["name"]].validate_tags(tags)
