@@ -5,7 +5,7 @@ from werkzeug.exceptions import BadRequest
 
 class ResourceNotFoundError(BadRequest):
     def __init__(self, message):
-        super(ResourceNotFoundError, self).__init__()
+        super().__init__()
         self.description = json.dumps(
             {"message": message, "__type": "ResourceNotFoundException"}
         )
@@ -16,7 +16,7 @@ class InvalidNameException(BadRequest):
     message = "1 validation error detected: Value '{}' at 'identityPoolName' failed to satisfy constraint: Member must satisfy regular expression pattern: [\\w\\s+=,.@-]+"
 
     def __init__(self, name):
-        super(InvalidNameException, self).__init__()
+        super().__init__()
         self.description = json.dumps(
             {
                 "message": InvalidNameException.message.format(name),
