@@ -2,11 +2,9 @@ import datetime
 import json
 import re
 
-from boto3 import Session
-
 from collections import OrderedDict
 from moto.core import BaseBackend, BaseModel
-from moto.core.utils import iso_8601_datetime_with_milliseconds
+from moto.core.utils import iso_8601_datetime_with_milliseconds, BackendDict
 from .exceptions import InvalidNameException, ResourceNotFoundError
 from .utils import get_random_identity_id
 
@@ -51,7 +49,7 @@ class CognitoIdentity(BaseModel):
 
 class CognitoIdentityBackend(BaseBackend):
     def __init__(self, region):
-        super(CognitoIdentityBackend, self).__init__()
+        super().__init__()
         self.region = region
         self.identity_pools = OrderedDict()
         self.pools_identities = {}
@@ -122,7 +120,6 @@ class CognitoIdentityBackend(BaseBackend):
         identity_pool_id,
         identity_pool_name,
         allow_unauthenticated,
-        allow_classic,
         login_providers,
         provider_name,
         provider_arns,
@@ -130,6 +127,9 @@ class CognitoIdentityBackend(BaseBackend):
         saml_providers,
         tags=None,
     ):
+        """
+        The AllowClassic-parameter has not yet been implemented
+        """
         pool = self.identity_pools[identity_pool_id]
         pool.identity_pool_name = pool.identity_pool_name or identity_pool_name
         if allow_unauthenticated is not None:
@@ -185,19 +185,12 @@ class CognitoIdentityBackend(BaseBackend):
         )
         return response
 
-    def list_identities(self, identity_pool_id, max_results=123):
+    def list_identities(self, identity_pool_id):
+        """
+        The MaxResults-parameter has not yet been implemented
+        """
         response = json.dumps(self.pools_identities[identity_pool_id])
         return response
 
 
-cognitoidentity_backends = {}
-for region in Session().get_available_regions("cognito-identity"):
-    cognitoidentity_backends[region] = CognitoIdentityBackend(region)
-for region in Session().get_available_regions(
-    "cognito-identity", partition_name="aws-us-gov"
-):
-    cognitoidentity_backends[region] = CognitoIdentityBackend(region)
-for region in Session().get_available_regions(
-    "cognito-identity", partition_name="aws-cn"
-):
-    cognitoidentity_backends[region] = CognitoIdentityBackend(region)
+cognitoidentity_backends = BackendDict(CognitoIdentityBackend, "cognito-identity")
