@@ -54,7 +54,8 @@ from moto.core import ACCOUNT_ID as DEFAULT_ACCOUNT_ID
 from moto.core.responses import AWSServiceSpec
 from moto.core.utils import BackendDict
 from moto.iam.config import role_config_query, policy_config_query
-from moto.s3.config import s3_account_public_access_block_query, s3_config_query
+from moto.s3.config import s3_config_query
+from moto.s3control.config import s3_account_public_access_block_query
 from moto.utilities.utils import load_resource
 
 
@@ -429,8 +430,10 @@ class OrganizationConformancePack(ConfigEmptyDictable):
         self.delivery_s3_key_prefix = delivery_s3_key_prefix
         self.excluded_accounts = excluded_accounts or []
         self.last_update_time = datetime2int(datetime.utcnow())
-        self.organization_conformance_pack_arn = "arn:aws:config:{0}:{1}:organization-conformance-pack/{2}".format(
-            region, DEFAULT_ACCOUNT_ID, self._unique_pack_name
+        self.organization_conformance_pack_arn = (
+            "arn:aws:config:{0}:{1}:organization-conformance-pack/{2}".format(
+                region, DEFAULT_ACCOUNT_ID, self._unique_pack_name
+            )
         )
         self.organization_conformance_pack_name = name
 
@@ -640,8 +643,9 @@ class Source(ConfigEmptyDictable):
         # operations, only load it if needed.
         from moto.awslambda import lambda_backends
 
-        lambda_func = lambda_backends[region].get_function(source_identifier)
-        if not lambda_func:
+        try:
+            lambda_backends[region].get_function(source_identifier)
+        except Exception:
             raise InsufficientPermissionsException(
                 f"The AWS Lambda function {source_identifier} cannot be "
                 f"invoked. Check the specified function ARN, and check the "
@@ -852,6 +856,12 @@ class ConfigBackend(BaseBackend):
         self.organization_conformance_packs = {}
         self.config_rules = {}
         self.config_schema = None
+        self.region = region
+
+    def reset(self):
+        region = self.region
+        self.__dict__ = {}
+        self.__init__(region)
 
     @staticmethod
     def default_vpc_endpoint_service(service_region, zones):
@@ -893,7 +903,7 @@ class ConfigBackend(BaseBackend):
                 self.config_schema.shapes["MaximumExecutionFrequency"]["enum"],
             )
 
-    def put_configuration_aggregator(self, config_aggregator, region):
+    def put_configuration_aggregator(self, config_aggregator):
         # Validate the name:
         if len(config_aggregator["ConfigurationAggregatorName"]) > 256:
             raise NameTooLongException(
@@ -964,7 +974,7 @@ class ConfigBackend(BaseBackend):
         ):
             aggregator = ConfigAggregator(
                 config_aggregator["ConfigurationAggregatorName"],
-                region,
+                self.region,
                 account_sources=account_sources,
                 org_source=org_source,
                 tags=tags,
@@ -1034,7 +1044,7 @@ class ConfigBackend(BaseBackend):
         del self.config_aggregators[config_aggregator]
 
     def put_aggregation_authorization(
-        self, current_region, authorized_account, authorized_region, tags
+        self, authorized_account, authorized_region, tags
     ):
         # Tag validation:
         tags = validate_tags(tags or [])
@@ -1044,7 +1054,7 @@ class ConfigBackend(BaseBackend):
         agg_auth = self.aggregation_authorizations.get(key)
         if not agg_auth:
             agg_auth = ConfigAggregationAuthorization(
-                current_region, authorized_account, authorized_region, tags=tags
+                self.region, authorized_account, authorized_region, tags=tags
             )
             self.aggregation_authorizations[
                 "{}/{}".format(authorized_account, authorized_region)
@@ -1614,7 +1624,6 @@ class ConfigBackend(BaseBackend):
 
     def put_organization_conformance_pack(
         self,
-        region,
         name,
         template_s3_uri,
         template_body,
@@ -1646,7 +1655,7 @@ class ConfigBackend(BaseBackend):
             )
         else:
             pack = OrganizationConformancePack(
-                region=region,
+                region=self.region,
                 name=name,
                 delivery_s3_bucket=delivery_s3_bucket,
                 delivery_s3_key_prefix=delivery_s3_key_prefix,
@@ -1815,7 +1824,7 @@ class ConfigBackend(BaseBackend):
             ]
         }
 
-    def put_config_rule(self, region, config_rule, tags=None):
+    def put_config_rule(self, config_rule, tags=None):
         """Add/Update config rule for evaluating resource compliance.
 
         TBD - Only the "accounting" of config rules are handled at the
@@ -1866,14 +1875,14 @@ class ConfigBackend(BaseBackend):
                 )
 
             # Update the current rule.
-            rule.modify_fields(region, config_rule, tags)
+            rule.modify_fields(self.region, config_rule, tags)
         else:
             # Create a new ConfigRule if the limit hasn't been reached.
             if len(self.config_rules) == ConfigRule.MAX_RULES:
                 raise MaxNumberOfConfigRulesExceededException(
                     rule_name, ConfigRule.MAX_RULES
                 )
-            rule = ConfigRule(region, config_rule, tags)
+            rule = ConfigRule(self.region, config_rule, tags)
             self.config_rules[rule_name] = rule
         return ""
 
