@@ -305,11 +305,11 @@ def tags_from_query_string(
             tag_index = key.replace(prefix + ".", "").replace("." + key_suffix, "")
             tag_key = querystring_dict.get(
                 "{prefix}.{index}.{key_suffix}".format(
-                    prefix=prefix, index=tag_index, key_suffix=key_suffix,
+                    prefix=prefix, index=tag_index, key_suffix=key_suffix
                 )
             )[0]
             tag_value_key = "{prefix}.{index}.{value_suffix}".format(
-                prefix=prefix, index=tag_index, value_suffix=value_suffix,
+                prefix=prefix, index=tag_index, value_suffix=value_suffix
             )
             if tag_value_key in querystring_dict:
                 response_values[tag_key] = querystring_dict.get(tag_value_key)[0]
@@ -381,7 +381,7 @@ def merge_dicts(dict1, dict2, remove_nulls=False):
 
 def aws_api_matches(pattern, string):
     """
-        AWS API can match a value based on a glob, or an exact match
+    AWS API can match a value based on a glob, or an exact match
     """
     # use a negative lookback regex to match stars that are not prefixed with a backslash
     # and replace all stars not prefixed w/ a backslash with '.*' to take this from "glob" to PCRE syntax
@@ -400,6 +400,14 @@ def aws_api_matches(pattern, string):
         return False
 
 
+def extract_region_from_aws_authorization(string):
+    auth = string or ""
+    region = re.sub(r".*Credential=[^/]+/[^/]+/([^/]+)/.*", r"\1", auth)
+    if region == auth:
+        return None
+    return region
+
+
 class BackendDict(dict):
     def __init__(self, fn, service_name):
         self.fn = fn
