@@ -10,9 +10,16 @@ class AlreadyExistsException(DataBrewClientError):
         super().__init__("AlreadyExistsException", "%s already exists." % (typ))
 
 
-class RecipeAlreadyExistsException(AlreadyExistsException):
-    def __init__(self):
-        super().__init__("Recipe")
+class ConflictException(DataBrewClientError):
+    code = 409
+
+    def __init__(self, message, **kwargs):
+        super().__init__("ConflictException", message, **kwargs)
+
+
+class ValidationException(DataBrewClientError):
+    def __init__(self, message, **kwargs):
+        super().__init__("ValidationException", message, **kwargs)
 
 
 class RulesetAlreadyExistsException(AlreadyExistsException):
@@ -25,9 +32,11 @@ class EntityNotFoundException(DataBrewClientError):
         super().__init__("EntityNotFoundException", msg)
 
 
-class RecipeNotFoundException(EntityNotFoundException):
-    def __init__(self, recipe_name):
-        super().__init__("Recipe %s not found." % recipe_name)
+class ResourceNotFoundException(DataBrewClientError):
+    code = 404
+
+    def __init__(self, message, **kwargs):
+        super().__init__("ResourceNotFoundException", message, **kwargs)
 
 
 class RulesetNotFoundException(EntityNotFoundException):
