@@ -1,8 +1,7 @@
-from moto.core.responses import BaseResponse
-from moto.ec2.utils import filters_from_querystring
+from ._base_response import EC2BaseResponse
 
 
-class CustomerGateways(BaseResponse):
+class CustomerGateways(EC2BaseResponse):
     def create_customer_gateway(self):
         # raise NotImplementedError('CustomerGateways(AmazonVPC).create_customer_gateway is not yet implemented')
         gateway_type = self._get_param("Type")
@@ -26,7 +25,7 @@ class CustomerGateways(BaseResponse):
 
     def describe_customer_gateways(self):
         self.error_on_dryrun()
-        filters = filters_from_querystring(self.querystring)
+        filters = self._filters_from_querystring()
         customer_gateway_ids = self._get_multi_param("CustomerGatewayId")
         customer_gateways = self.ec2_backend.get_all_customer_gateways(
             filters, customer_gateway_ids
