@@ -1,4 +1,3 @@
-from __future__ import unicode_literals
 from moto.core.responses import BaseResponse
 
 
@@ -43,14 +42,21 @@ class SpotFleets(BaseResponse):
         return template.render(successful=successful)
 
     def request_spot_fleet(self):
-        spot_config = self._get_dict_param("SpotFleetRequestConfig.")
-        spot_price = spot_config.get("spot_price")
-        target_capacity = spot_config["target_capacity"]
-        iam_fleet_role = spot_config["iam_fleet_role"]
-        allocation_strategy = spot_config["allocation_strategy"]
+        spot_config = self._get_multi_param_dict("SpotFleetRequestConfig")
+        spot_price = spot_config.get("SpotPrice")
+        target_capacity = spot_config["TargetCapacity"]
+        iam_fleet_role = spot_config["IamFleetRole"]
+        allocation_strategy = spot_config["AllocationStrategy"]
+        instance_interruption_behaviour = spot_config.get(
+            "InstanceInterruptionBehavior"
+        )
 
-        launch_specs = self._get_list_prefix(
-            "SpotFleetRequestConfig.LaunchSpecifications"
+        launch_specs = spot_config.get("LaunchSpecifications")
+        launch_template_config = list(
+            self._get_params()
+            .get("SpotFleetRequestConfig", {})
+            .get("LaunchTemplateConfigs", {})
+            .values()
         )
 
         request = self.ec2_backend.request_spot_fleet(
@@ -59,6 +65,8 @@ class SpotFleets(BaseResponse):
             iam_fleet_role=iam_fleet_role,
             allocation_strategy=allocation_strategy,
             launch_specs=launch_specs,
+            launch_template_config=launch_template_config,
+            instance_interruption_behaviour=instance_interruption_behaviour,
         )
 
         template = self.response_template(REQUEST_SPOT_FLEET_TEMPLATE)
