@@ -66,12 +66,13 @@ class Repository(BaseObject, CloudFormationModel):
         self,
         region_name,
         repository_name,
+        registry_id,
         encryption_config,
         image_scan_config,
         image_tag_mutablility,
     ):
         self.region_name = region_name
-        self.registry_id = DEFAULT_REGISTRY_ID
+        self.registry_id = registry_id or DEFAULT_REGISTRY_ID
         self.arn = (
             f"arn:aws:ecr:{region_name}:{self.registry_id}:repository/{repository_name}"
         )
@@ -152,8 +153,8 @@ class Repository(BaseObject, CloudFormationModel):
         ecr_backend.delete_repository(self.name)
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["Arn", "RepositoryUri"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["Arn", "RepositoryUri"]
 
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
@@ -190,6 +191,7 @@ class Repository(BaseObject, CloudFormationModel):
             # RepositoryName is optional in CloudFormation, thus create a random
             # name if necessary
             repository_name=resource_name,
+            registry_id=None,
             encryption_config=encryption_config,
             image_scan_config=image_scan_config,
             image_tag_mutablility=image_tag_mutablility,
@@ -242,7 +244,7 @@ class Image(BaseObject):
         self.last_scan = None
 
     def _create_digest(self):
-        image_contents = "docker_image{0}".format(int(random() * 10 ** 6))
+        image_contents = "docker_image{0}".format(int(random() * 10**6))
         self.image_digest = (
             "sha256:%s" % hashlib.sha256(image_contents.encode("utf-8")).hexdigest()
         )
@@ -357,7 +359,7 @@ class ECRBackend(BaseBackend):
             "VpcEndpointPolicySupported": True,
         }
         return BaseBackend.default_vpc_endpoint_service_factory(
-            service_region, zones, "api.ecr", special_service_name="ecr.api",
+            service_region, zones, "api.ecr", special_service_name="ecr.api"
         ) + [docker_endpoint]
 
     def _get_repository(self, name, registry_id=None) -> Repository:
@@ -406,6 +408,7 @@ class ECRBackend(BaseBackend):
     def create_repository(
         self,
         repository_name,
+        registry_id,
         encryption_config,
         image_scan_config,
         image_tag_mutablility,
@@ -417,6 +420,7 @@ class ECRBackend(BaseBackend):
         repository = Repository(
             region_name=self.region_name,
             repository_name=repository_name,
+            registry_id=registry_id,
             encryption_config=encryption_config,
             image_scan_config=image_scan_config,
             image_tag_mutablility=image_tag_mutablility,
@@ -501,13 +505,10 @@ class ECRBackend(BaseBackend):
             existing_images[0].update_tag(image_tag)
             return existing_images[0]
 
-    def batch_get_image(
-        self,
-        repository_name,
-        registry_id=None,
-        image_ids=None,
-        accepted_media_types=None,
-    ):
+    def batch_get_image(self, repository_name, registry_id=None, image_ids=None):
+        """
+        The parameter AcceptedMediaTypes has not yet been implemented
+        """
         if repository_name in self.repositories:
             repository = self.repositories[repository_name]
         else:
@@ -630,24 +631,24 @@ class ECRBackend(BaseBackend):
                     else:
                         repository.images.remove(image)
 
-                if not image_found:
-                    failure_response = {
-                        "imageId": {},
-                        "failureCode": "ImageNotFound",
-                        "failureReason": "Requested image not found",
-                    }
+            if not image_found:
+                failure_response = {
+                    "imageId": {},
+                    "failureCode": "ImageNotFound",
+                    "failureReason": "Requested image not found",
+                }
 
-                    if "imageDigest" in image_id:
-                        failure_response["imageId"]["imageDigest"] = image_id.get(
-                            "imageDigest", "null"
-                        )
+                if "imageDigest" in image_id:
+                    failure_response["imageId"]["imageDigest"] = image_id.get(
+                        "imageDigest", "null"
+                    )
 
-                    if "imageTag" in image_id:
-                        failure_response["imageId"]["imageTag"] = image_id.get(
-                            "imageTag", "null"
-                        )
+                if "imageTag" in image_id:
+                    failure_response["imageId"]["imageTag"] = image_id.get(
+                        "imageTag", "null"
+                    )
 
-                    response["failures"].append(failure_response)
+                response["failures"].append(failure_response)
 
         return response
 
@@ -950,4 +951,4 @@ class ECRBackend(BaseBackend):
         }
 
 
-ecr_backends = BackendDict(ECRBackend, "ec2")
+ecr_backends = BackendDict(ECRBackend, "ecr")
