@@ -19,8 +19,8 @@ class ECRResponse(BaseResponse):
         except ValueError:
             return {}
 
-    def _get_param(self, param, if_none=None):
-        return self.request_params.get(param, if_none)
+    def _get_param(self, param_name, if_none=None):
+        return self.request_params.get(param_name, if_none)
 
     def create_repository(self):
         repository_name = self._get_param("repositoryName")
@@ -106,10 +106,9 @@ class ECRResponse(BaseResponse):
         repository_str = self._get_param("repositoryName")
         registry_id = self._get_param("registryId")
         image_ids = self._get_param("imageIds")
-        accepted_media_types = self._get_param("acceptedMediaTypes")
 
         response = self.ecr_backend.batch_get_image(
-            repository_str, registry_id, image_ids, accepted_media_types
+            repository_str, registry_id, image_ids
         )
         return json.dumps(response)
 
@@ -125,7 +124,7 @@ class ECRResponse(BaseResponse):
 
         return json.dumps(
             self.ecr_backend.delete_repository_policy(
-                registry_id=registry_id, repository_name=repository_name,
+                registry_id=registry_id, repository_name=repository_name
             )
         )
 
@@ -160,7 +159,7 @@ class ECRResponse(BaseResponse):
 
         return json.dumps(
             self.ecr_backend.get_repository_policy(
-                registry_id=registry_id, repository_name=repository_name,
+                registry_id=registry_id, repository_name=repository_name
             )
         )
 
@@ -252,7 +251,7 @@ class ECRResponse(BaseResponse):
 
         return json.dumps(
             self.ecr_backend.get_lifecycle_policy(
-                registry_id=registry_id, repository_name=repository_name,
+                registry_id=registry_id, repository_name=repository_name
             )
         )
 
@@ -262,7 +261,7 @@ class ECRResponse(BaseResponse):
 
         return json.dumps(
             self.ecr_backend.delete_lifecycle_policy(
-                registry_id=registry_id, repository_name=repository_name,
+                registry_id=registry_id, repository_name=repository_name
             )
         )
 
