@@ -61,7 +61,7 @@ class AccountSetting(BaseObject):
 
 
 class Cluster(BaseObject, CloudFormationModel):
-    def __init__(self, cluster_name, region_name):
+    def __init__(self, cluster_name, region_name, cluster_settings=None):
         self.active_services_count = 0
         self.arn = "arn:aws:ecs:{0}:{1}:cluster/{2}".format(
             region_name, ACCOUNT_ID, cluster_name
@@ -72,6 +72,7 @@ class Cluster(BaseObject, CloudFormationModel):
         self.running_tasks_count = 0
         self.status = "ACTIVE"
         self.region_name = region_name
+        self.settings = cluster_settings
 
     @property
     def physical_resource_id(self):
@@ -122,8 +123,8 @@ class Cluster(BaseObject, CloudFormationModel):
             return original_resource
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["Arn"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["Arn"]
 
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
@@ -240,7 +241,7 @@ class TaskDefinition(BaseObject, CloudFormationModel):
         properties = cloudformation_json["Properties"]
 
         family = properties.get(
-            "Family", "task-definition-{0}".format(int(random() * 10 ** 6))
+            "Family", "task-definition-{0}".format(int(random() * 10**6))
         )
         container_definitions = remap_nested_keys(
             properties.get("ContainerDefinitions", []), pascal_to_camelcase
@@ -258,7 +259,7 @@ class TaskDefinition(BaseObject, CloudFormationModel):
     ):
         properties = cloudformation_json["Properties"]
         family = properties.get(
-            "Family", "task-definition-{0}".format(int(random() * 10 ** 6))
+            "Family", "task-definition-{0}".format(int(random() * 10**6))
         )
         container_definitions = properties["ContainerDefinitions"]
         volumes = properties.get("Volumes")
@@ -289,9 +290,10 @@ class Task(BaseObject):
         container_instance_arn,
         resource_requirements,
         backend,
-        overrides={},
+        launch_type="",
+        overrides=None,
         started_by="",
-        tags=[],
+        tags=None,
     ):
         self.id = str(uuid.uuid4())
         self.cluster_name = cluster.name
@@ -300,10 +302,11 @@ class Task(BaseObject):
         self.last_status = "RUNNING"
         self.desired_status = "RUNNING"
         self.task_definition_arn = task_definition.arn
-        self.overrides = overrides
+        self.overrides = overrides or {}
         self.containers = []
         self.started_by = started_by
-        self.tags = tags
+        self.tags = tags or []
+        self.launch_type = launch_type
         self.stopped_reason = ""
         self.resource_requirements = resource_requirements
         self.region_name = cluster.region_name
@@ -324,6 +327,31 @@ class Task(BaseObject):
         return response_object
 
 
+class CapacityProvider(BaseObject):
+    def __init__(self, region_name, name, asg_details, tags):
+        self._id = str(uuid.uuid4())
+        self.capacity_provider_arn = f"arn:aws:ecs:{region_name}:{ACCOUNT_ID}:capacity_provider/{name}/{self._id}"
+        self.name = name
+        self.status = "ACTIVE"
+        self.auto_scaling_group_provider = asg_details
+        self.tags = tags
+
+
+class CapacityProviderFailure(BaseObject):
+    def __init__(self, reason, name, region_name):
+        self.reason = reason
+        self.arn = "arn:aws:ecs:{0}:{1}:capacity_provider/{2}".format(
+            region_name, ACCOUNT_ID, name
+        )
+
+    @property
+    def response_object(self):
+        response_object = self.gen_response_object()
+        response_object["reason"] = self.reason
+        response_object["arn"] = self.arn
+        return response_object
+
+
 class Service(BaseObject, CloudFormationModel):
     def __init__(
         self,
@@ -359,7 +387,7 @@ class Service(BaseObject, CloudFormationModel):
                 {
                     "createdAt": datetime.now(pytz.utc),
                     "desiredCount": self.desired_count,
-                    "id": "ecs-svc/{}".format(randint(0, 32 ** 12)),
+                    "id": "ecs-svc/{}".format(randint(0, 32**12)),
                     "launchType": self.launch_type,
                     "pendingCount": self.desired_count,
                     "runningCount": 0,
@@ -482,8 +510,8 @@ class Service(BaseObject, CloudFormationModel):
             )
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["Name"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["Name"]
 
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
@@ -683,7 +711,7 @@ class TaskSet(BaseObject):
         self.createdAt = datetime.now(pytz.utc)
         self.updatedAt = datetime.now(pytz.utc)
         self.stabilityStatusAt = datetime.now(pytz.utc)
-        self.id = "ecs-svc/{}".format(randint(0, 32 ** 12))
+        self.id = "ecs-svc/{}".format(randint(0, 32**12))
         self.service_arn = ""
         self.cluster_arn = ""
 
@@ -714,9 +742,18 @@ class TaskSet(BaseObject):
 
 
 class EC2ContainerServiceBackend(BaseBackend):
+    """
+    ECS resources use the new ARN format by default.
+    Use the following environment variable to revert back to the old/short ARN format:
+    `MOTO_ECS_NEW_ARN=false`
+
+    AWS reference: https://aws.amazon.com/blogs/compute/migrating-your-amazon-ecs-deployment-to-the-new-arn-and-resource-id-format-2/
+    """
+
     def __init__(self, region_name):
-        super(EC2ContainerServiceBackend, self).__init__()
+        super().__init__()
         self.account_settings = dict()
+        self.capacity_providers = dict()
         self.clusters = {}
         self.task_definitions = {}
         self.tasks = {}
@@ -750,6 +787,13 @@ class EC2ContainerServiceBackend(BaseBackend):
 
         return cluster
 
+    def create_capacity_provider(self, name, asg_details, tags):
+        capacity_provider = CapacityProvider(self.region_name, name, asg_details, tags)
+        self.capacity_providers[name] = capacity_provider
+        if tags:
+            self.tagger.tag_resource(capacity_provider.capacity_provider_arn, tags)
+        return capacity_provider
+
     def describe_task_definition(self, task_definition_str):
         task_definition_name = task_definition_str.split("/")[-1]
         if ":" in task_definition_name:
@@ -767,13 +811,42 @@ class EC2ContainerServiceBackend(BaseBackend):
         else:
             raise Exception("{0} is not a task_definition".format(task_definition_name))
 
-    def create_cluster(self, cluster_name, tags=None):
-        cluster = Cluster(cluster_name, self.region_name)
+    def create_cluster(self, cluster_name, tags=None, cluster_settings=None):
+        """
+        The following parameters are not yet implemented: configuration, capacityProviders, defaultCapacityProviderStrategy
+        """
+        cluster = Cluster(cluster_name, self.region_name, cluster_settings)
         self.clusters[cluster_name] = cluster
         if tags:
             self.tagger.tag_resource(cluster.arn, tags)
         return cluster
 
+    def _get_provider(self, name_or_arn):
+        for provider in self.capacity_providers.values():
+            if (
+                provider.name == name_or_arn
+                or provider.capacity_provider_arn == name_or_arn
+            ):
+                return provider
+
+    def describe_capacity_providers(self, names):
+        providers = []
+        failures = []
+        for name in names:
+            provider = self._get_provider(name)
+            if provider:
+                providers.append(provider)
+            else:
+                failures.append(
+                    CapacityProviderFailure("MISSING", name, self.region_name)
+                )
+        return providers, failures
+
+    def delete_capacity_provider(self, name_or_arn):
+        provider = self._get_provider(name_or_arn)
+        self.capacity_providers.pop(provider.name)
+        return provider
+
     def list_clusters(self):
         """
         maxSize and pagination not implemented
@@ -887,7 +960,14 @@ class EC2ContainerServiceBackend(BaseBackend):
             raise TaskDefinitionNotFoundException
 
     def run_task(
-        self, cluster_str, task_definition_str, count, overrides, started_by, tags
+        self,
+        cluster_str,
+        task_definition_str,
+        count,
+        overrides,
+        started_by,
+        tags,
+        launch_type,
     ):
         cluster = self._get_cluster(cluster_str)
 
@@ -917,7 +997,7 @@ class EC2ContainerServiceBackend(BaseBackend):
             container_instance_arn = container_instance.container_instance_arn
             try_to_place = True
             while try_to_place:
-                can_be_placed, message = self._can_be_placed(
+                can_be_placed = self._can_be_placed(
                     container_instance, resource_requirements
                 )
                 if can_be_placed:
@@ -930,6 +1010,7 @@ class EC2ContainerServiceBackend(BaseBackend):
                         overrides=overrides or {},
                         started_by=started_by or "",
                         tags=tags or [],
+                        launch_type=launch_type or "",
                     )
                     self.update_container_instance_resources(
                         container_instance, resource_requirements
@@ -1002,14 +1083,14 @@ class EC2ContainerServiceBackend(BaseBackend):
             elif resource.get("name") == "PORTS":
                 reserved_ports = resource.get("stringSetValue")
         if task_resource_requirements.get("CPU") > remaining_cpu:
-            return False, "Not enough CPU credits"
+            return False
         if task_resource_requirements.get("MEMORY") > remaining_memory:
-            return False, "Not enough memory"
+            return False
         ports_needed = task_resource_requirements.get("PORTS")
         for port in ports_needed:
             if str(port) in reserved_ports:
-                return False, "Port clash"
-        return True, "Can be placed"
+                return False
+        return True
 
     def start_task(
         self,
@@ -1058,7 +1139,7 @@ class EC2ContainerServiceBackend(BaseBackend):
         if not tasks:
             raise InvalidParameterException("Tasks cannot be empty.")
         response = []
-        for cluster, cluster_tasks in self.tasks.items():
+        for cluster_tasks in self.tasks.values():
             for task_arn, task in cluster_tasks.items():
                 task_id = task_arn.split("/")[-1]
                 if (
@@ -1080,7 +1161,7 @@ class EC2ContainerServiceBackend(BaseBackend):
     ):
         filtered_tasks = []
         for cluster, tasks in self.tasks.items():
-            for arn, task in tasks.items():
+            for task in tasks.values():
                 filtered_tasks.append(task)
         if cluster_str:
             cluster = self._get_cluster(cluster_str)
@@ -1147,6 +1228,15 @@ class EC2ContainerServiceBackend(BaseBackend):
             "Could not find task {} on cluster {}".format(task_str, cluster.name)
         )
 
+    def _get_service(self, cluster_str, service_str):
+        cluster = self._get_cluster(cluster_str)
+        for service in self.services.values():
+            if service.cluster_name == cluster.name and (
+                service.name == service_str or service.arn == service_str
+            ):
+                return service
+        raise ServiceNotFoundException
+
     def create_service(
         self,
         cluster_str,
@@ -1193,9 +1283,8 @@ class EC2ContainerServiceBackend(BaseBackend):
     def list_services(self, cluster_str, scheduling_strategy=None):
         cluster_name = cluster_str.split("/")[-1]
         service_arns = []
-        for key, value in self.services.items():
+        for key, service in self.services.items():
             if cluster_name + ":" in key:
-                service = self.services[key]
                 if (
                     scheduling_strategy is None
                     or service.scheduling_strategy == scheduling_strategy
@@ -1206,31 +1295,19 @@ class EC2ContainerServiceBackend(BaseBackend):
 
     def describe_services(self, cluster_str, service_names_or_arns):
         cluster = self._get_cluster(cluster_str)
+        service_names = [name.split("/")[-1] for name in service_names_or_arns]
 
         result = []
         failures = []
-        for existing_service_name, existing_service_obj in sorted(
-            self.services.items()
-        ):
-            for requested_name_or_arn in service_names_or_arns:
-                cluster_service_pair = "{0}:{1}".format(
-                    cluster.name, requested_name_or_arn
+        for name in service_names:
+            cluster_service_pair = "{0}:{1}".format(cluster.name, name)
+            if cluster_service_pair in self.services:
+                result.append(self.services[cluster_service_pair])
+            else:
+                missing_arn = (
+                    f"arn:aws:ecs:{self.region_name}:{ACCOUNT_ID}:service/{name}"
                 )
-                if (
-                    cluster_service_pair == existing_service_name
-                    or existing_service_obj.arn == requested_name_or_arn
-                ):
-                    result.append(existing_service_obj)
-                else:
-                    service_name = requested_name_or_arn.split("/")[-1]
-                    failures.append(
-                        {
-                            "arn": "arn:aws:ecs:eu-central-1:{0}:service/{1}".format(
-                                ACCOUNT_ID, service_name
-                            ),
-                            "reason": "MISSING",
-                        }
-                    )
+                failures.append({"arn": missing_arn, "reason": "MISSING"})
 
         return result, failures
 
@@ -1255,18 +1332,17 @@ class EC2ContainerServiceBackend(BaseBackend):
 
     def delete_service(self, cluster_name, service_name, force):
         cluster = self._get_cluster(cluster_name)
-        cluster_service_pair = "{0}:{1}".format(cluster.name, service_name)
+        service = self._get_service(cluster_name, service_name)
 
-        if cluster_service_pair in self.services:
-            service = self.services[cluster_service_pair]
-            if service.desired_count > 0 and not force:
-                raise InvalidParameterException(
-                    "The service cannot be stopped while it is scaled above 0."
-                )
-            else:
-                return self.services.pop(cluster_service_pair)
+        cluster_service_pair = "{0}:{1}".format(cluster.name, service.name)
+
+        service = self.services[cluster_service_pair]
+        if service.desired_count > 0 and not force:
+            raise InvalidParameterException(
+                "The service cannot be stopped while it is scaled above 0."
+            )
         else:
-            raise ServiceNotFoundException
+            return self.services.pop(cluster_service_pair)
 
     def register_container_instance(self, cluster_str, ec2_instance_id):
         cluster_name = cluster_str.split("/")[-1]
@@ -1374,7 +1450,6 @@ class EC2ContainerServiceBackend(BaseBackend):
     def deregister_container_instance(self, cluster_str, container_instance_str, force):
         cluster = self._get_cluster(cluster_str)
 
-        failures = []
         container_instance_id = container_instance_str.split("/")[-1]
         container_instance = self.container_instances[cluster.name].get(
             container_instance_id
@@ -1393,7 +1468,7 @@ class EC2ContainerServiceBackend(BaseBackend):
             ] = container_instance
         del self.container_instances[cluster.name][container_instance_id]
         self._respond_to_cluster_state_update(cluster_str)
-        return container_instance, failures
+        return container_instance
 
     def _respond_to_cluster_state_update(self, cluster_str):
         self._get_cluster(cluster_str)
@@ -1453,9 +1528,10 @@ class EC2ContainerServiceBackend(BaseBackend):
         cluster_name=None,
         attr_name=None,
         attr_value=None,
-        max_results=None,
-        next_token=None,
     ):
+        """
+        Pagination is not yet implemented
+        """
         if target_type != "container-instance":
             raise JsonRESTError(
                 "InvalidParameterException", "targetType must be container-instance"
@@ -1538,9 +1614,10 @@ class EC2ContainerServiceBackend(BaseBackend):
                     "TargetNotFoundException", "Could not find {0}".format(target_id)
                 )
 
-    def list_task_definition_families(
-        self, family_prefix=None, status=None, max_results=None, next_token=None
-    ):
+    def list_task_definition_families(self, family_prefix=None):
+        """
+        The Status and pagination parameters are not yet implemented
+        """
         for task_fam in self.task_definitions:
             if family_prefix is not None and not task_fam.startswith(family_prefix):
                 continue
@@ -1550,9 +1627,15 @@ class EC2ContainerServiceBackend(BaseBackend):
     @staticmethod
     def _parse_resource_arn(resource_arn):
         match = re.match(
-            "^arn:aws:ecs:(?P<region>[^:]+):(?P<account_id>[^:]+):(?P<service>[^:]+)/(?P<id>.*)$",
+            "^arn:aws:ecs:(?P<region>[^:]+):(?P<account_id>[^:]+):(?P<service>[^:]+)/(?P<cluster_id>[^:]+)/(?P<id>.*)$",
             resource_arn,
         )
+        if not match:
+            # maybe a short-format ARN
+            match = re.match(
+                "^arn:aws:ecs:(?P<region>[^:]+):(?P<account_id>[^:]+):(?P<service>[^:]+)/(?P<id>.*)$",
+                resource_arn,
+            )
         if not match:
             raise JsonRESTError(
                 "InvalidParameterException", "The ARN provided is invalid."
@@ -1567,14 +1650,12 @@ class EC2ContainerServiceBackend(BaseBackend):
                 for revision in task_definition.values():
                     if revision.arn == resource_arn:
                         return revision.tags
-            else:
-                raise TaskDefinitionNotFoundException()
+            raise TaskDefinitionNotFoundException()
         elif parsed_arn["service"] == "service":
             for service in self.services.values():
                 if service.arn == resource_arn:
                     return service.tags
-            else:
-                raise ServiceNotFoundException
+            raise ServiceNotFoundException
         raise NotImplementedError()
 
     def _get_last_task_definition_revision_id(self, family):
@@ -1590,8 +1671,7 @@ class EC2ContainerServiceBackend(BaseBackend):
                 if service.arn == resource_arn:
                     service.tags = self._merge_tags(service.tags, tags)
                     return {}
-            else:
-                raise ServiceNotFoundException
+            raise ServiceNotFoundException
         raise NotImplementedError()
 
     def _merge_tags(self, existing_tags, new_tags):
@@ -1616,8 +1696,7 @@ class EC2ContainerServiceBackend(BaseBackend):
                         tag for tag in service.tags if tag["key"] not in tag_keys
                     ]
                     return {}
-            else:
-                raise ServiceNotFoundException
+            raise ServiceNotFoundException
         raise NotImplementedError()
 
     def create_task_set(
@@ -1698,7 +1777,10 @@ class EC2ContainerServiceBackend(BaseBackend):
 
         return task_set_results
 
-    def delete_task_set(self, cluster, service, task_set, force=False):
+    def delete_task_set(self, cluster, service, task_set):
+        """
+        The Force-parameter is not yet implemented
+        """
         cluster_name = cluster.split("/")[-1]
         service_name = service.split("/")[-1]
 
@@ -1776,12 +1858,10 @@ class EC2ContainerServiceBackend(BaseBackend):
         self.account_settings.pop(name, None)
 
     def enable_long_arn_for_name(self, name):
-        if settings.ecs_new_arn_format():
-            return True
         account = self.account_settings.get(name, None)
-        if account and account.value == "enabled":
-            return True
-        return False
+        if account and account.value == "disabled":
+            return False
+        return settings.ecs_new_arn_format()
 
 
 ecs_backends = BackendDict(EC2ContainerServiceBackend, "ecs")
