@@ -22,15 +22,23 @@ class EC2ContainerServiceResponse(BaseResponse):
         except ValueError:
             return {}
 
-    def _get_param(self, param, if_none=None):
-        return self.request_params.get(param, if_none)
+    def _get_param(self, param_name, if_none=None):
+        return self.request_params.get(param_name, if_none)
+
+    def create_capacity_provider(self):
+        name = self._get_param("name")
+        asg_provider = self._get_param("autoScalingGroupProvider")
+        tags = self._get_param("tags")
+        provider = self.ecs_backend.create_capacity_provider(name, asg_provider, tags)
+        return json.dumps({"capacityProvider": provider.response_object})
 
     def create_cluster(self):
         cluster_name = self._get_param("clusterName")
         tags = self._get_param("tags")
+        settings = self._get_param("settings")
         if cluster_name is None:
             cluster_name = "default"
-        cluster = self.ecs_backend.create_cluster(cluster_name, tags)
+        cluster = self.ecs_backend.create_cluster(cluster_name, tags, settings)
         return json.dumps({"cluster": cluster.response_object})
 
     def list_clusters(self):
@@ -42,6 +50,21 @@ class EC2ContainerServiceResponse(BaseResponse):
             }
         )
 
+    def delete_capacity_provider(self):
+        name = self._get_param("capacityProvider")
+        provider = self.ecs_backend.delete_capacity_provider(name)
+        return json.dumps({"capacityProvider": provider.response_object})
+
+    def describe_capacity_providers(self):
+        names = self._get_param("capacityProviders")
+        providers, failures = self.ecs_backend.describe_capacity_providers(names)
+        return json.dumps(
+            {
+                "capacityProviders": [p.response_object for p in providers],
+                "failures": [p.response_object for p in failures],
+            }
+        )
+
     def describe_clusters(self):
         names = self._get_param("clusters")
         include = self._get_param("include")
@@ -319,11 +342,9 @@ class EC2ContainerServiceResponse(BaseResponse):
         attr_name = self._get_param("attributeName")
         attr_value = self._get_param("attributeValue")
         target_type = self._get_param("targetType")
-        max_results = self._get_param("maxResults")
-        next_token = self._get_param("nextToken")
 
         results = self.ecs_backend.list_attributes(
-            target_type, cluster_name, attr_name, attr_value, max_results, next_token
+            target_type, cluster_name, attr_name, attr_value
         )
         # Result will be [item will be {0 cluster_name, 1 arn, 2 name, 3 value}]
 
@@ -355,13 +376,7 @@ class EC2ContainerServiceResponse(BaseResponse):
 
     def list_task_definition_families(self):
         family_prefix = self._get_param("familyPrefix")
-        status = self._get_param("status")
-        max_results = self._get_param("maxResults")
-        next_token = self._get_param("nextToken")
-
-        results = self.ecs_backend.list_task_definition_families(
-            family_prefix, status, max_results, next_token
-        )
+        results = self.ecs_backend.list_task_definition_families(family_prefix)
 
         return json.dumps({"families": list(results)})
 
@@ -432,10 +447,7 @@ class EC2ContainerServiceResponse(BaseResponse):
         cluster_str = self._get_param("cluster")
         service_str = self._get_param("service")
         task_set = self._get_param("taskSet")
-        force = self._get_param("force")
-        task_set = self.ecs_backend.delete_task_set(
-            cluster_str, service_str, task_set, force
-        )
+        task_set = self.ecs_backend.delete_task_set(cluster_str, service_str, task_set)
         return json.dumps({"taskSet": task_set.response_object})
 
     def update_task_set(self):
