@@ -9,7 +9,7 @@ import time
 from copy import deepcopy
 from hashlib import md5
 
-from moto.core import ACCOUNT_ID, BaseBackend, CloudFormationModel
+from moto.core import ACCOUNT_ID, BaseBackend, BaseModel, CloudFormationModel
 from moto.core.utils import (
     camelcase_to_underscores,
     get_random_hex,
@@ -19,6 +19,7 @@ from moto.core.utils import (
 from moto.ec2 import ec2_backends
 from moto.ec2.exceptions import InvalidSubnetIdError
 from moto.efs.exceptions import (
+    AccessPointNotFound,
     BadRequest,
     FileSystemAlreadyExists,
     FileSystemInUse,
@@ -30,6 +31,7 @@ from moto.efs.exceptions import (
     SecurityGroupNotFound,
     SecurityGroupLimitExceeded,
 )
+from moto.utilities.tagging_service import TaggingService
 
 
 def _lookup_az_id(az_name):
@@ -40,6 +42,48 @@ def _lookup_az_id(az_name):
             return zone.zone_id
 
 
+class AccessPoint(BaseModel):
+    def __init__(
+        self,
+        region_name,
+        client_token,
+        file_system_id,
+        name,
+        posix_user,
+        root_directory,
+        context,
+    ):
+        self.access_point_id = get_random_hex(8)
+        self.access_point_arn = "arn:aws:elasticfilesystem:{region}:{user_id}:access-point/fsap-{file_system_id}".format(
+            region=region_name, user_id=ACCOUNT_ID, file_system_id=self.access_point_id
+        )
+        self.client_token = client_token
+        self.file_system_id = file_system_id
+        self.name = name
+        self.posix_user = posix_user
+
+        if not root_directory:
+            root_directory = {"Path": "/"}
+
+        self.root_directory = root_directory
+        self.context = context
+
+    def info_json(self):
+        tags = self.context.list_tags_for_resource(self.access_point_id)
+        return {
+            "ClientToken": self.client_token,
+            "Name": self.name,
+            "Tags": tags,
+            "AccessPointId": self.access_point_id,
+            "AccessPointArn": self.access_point_arn,
+            "FileSystemId": self.file_system_id,
+            "PosixUser": self.posix_user,
+            "RootDirectory": self.root_directory,
+            "OwnerId": ACCOUNT_ID,
+            "LifeCycleState": "available",
+        }
+
+
 class FileSystem(CloudFormationModel):
     """A model for an EFS File System Volume."""
 
@@ -48,16 +92,16 @@ class FileSystem(CloudFormationModel):
         region_name,
         creation_token,
         file_system_id,
-        performance_mode="generalPurpose",
-        encrypted=False,
-        kms_key_id=None,
-        throughput_mode="bursting",
-        provisioned_throughput_in_mibps=None,
-        availability_zone_name=None,
-        backup=False,
+        context,
+        performance_mode,
+        encrypted,
+        kms_key_id,
+        throughput_mode,
+        provisioned_throughput_in_mibps,
+        availability_zone_name,
+        backup,
         lifecycle_policies=None,
         file_system_policy=None,
-        tags=None,
     ):
         if availability_zone_name:
             backup = True
@@ -66,31 +110,20 @@ class FileSystem(CloudFormationModel):
 
         # Save given parameters
         self.creation_token = creation_token
-        self.performance_mode = performance_mode
-        self.encrypted = encrypted
+        self.performance_mode = performance_mode or "generalPurpose"
+        self.encrypted = encrypted or False
         self.kms_key_id = kms_key_id
-        self.throughput_mode = throughput_mode
+        self.throughput_mode = throughput_mode or "bursting"
         self.provisioned_throughput_in_mibps = provisioned_throughput_in_mibps
         self.availability_zone_name = availability_zone_name
         self.availability_zone_id = None
         if self.availability_zone_name:
             self.availability_zone_id = _lookup_az_id(self.availability_zone_name)
         self._backup = backup
-        self.lifecycle_policies = lifecycle_policies
+        self.lifecycle_policies = lifecycle_policies or []
         self.file_system_policy = file_system_policy
 
-        # Validate tag structure.
-        if tags is None:
-            self.tags = []
-        else:
-            if (
-                not isinstance(tags, list)
-                or not all(isinstance(tag, dict) for tag in tags)
-                or not all(set(tag.keys()) == {"Key", "Value"} for tag in tags)
-            ):
-                raise ValueError("Invalid tags: {}".format(tags))
-            else:
-                self.tags = tags
+        self._context = context
 
         # Generate AWS-assigned parameters
         self.file_system_id = file_system_id
@@ -135,8 +168,19 @@ class FileSystem(CloudFormationModel):
             for k, v in self.__dict__.items()
             if not k.startswith("_")
         }
-        ret["SizeInBytes"] = self.size_in_bytes
-        ret["NumberOfMountTargets"] = self.number_of_mount_targets
+        tags = self._context.list_tags_for_resource(self.file_system_id)
+        name = ""
+        for tag in tags:
+            if tag["Key"] == "Name":
+                name = tag["Value"]
+                break
+
+        ret.update(
+            Tags=tags,
+            SizeInBytes=self.size_in_bytes,
+            NumberOfMountTargets=self.number_of_mount_targets,
+            Name=name,
+        )
         return ret
 
     def add_mount_target(self, subnet, mount_target):
@@ -318,9 +362,11 @@ class EFSBackend(BaseBackend):
         super().__init__()
         self.region_name = region_name
         self.creation_tokens = set()
+        self.access_points = dict()
         self.file_systems_by_id = {}
         self.mount_targets_by_id = {}
         self.next_markers = {}
+        self.tagging_service = TaggingService()
 
     def reset(self):
         # preserve region
@@ -331,7 +377,8 @@ class EFSBackend(BaseBackend):
     def _mark_description(self, corpus, max_items):
         if max_items < len(corpus):
             new_corpus = corpus[max_items:]
-            new_hash = md5(json.dumps(new_corpus).encode("utf-8"))
+            new_corpus_dict = [c.info_json() for c in new_corpus]
+            new_hash = md5(json.dumps(new_corpus_dict).encode("utf-8"))
             next_marker = new_hash.hexdigest()
             self.next_markers[next_marker] = new_corpus
         else:
@@ -342,7 +389,18 @@ class EFSBackend(BaseBackend):
     def ec2_backend(self):
         return ec2_backends[self.region_name]
 
-    def create_file_system(self, creation_token, **params):
+    def create_file_system(
+        self,
+        creation_token,
+        performance_mode,
+        encrypted,
+        kms_key_id,
+        throughput_mode,
+        provisioned_throughput_in_mibps,
+        availability_zone_name,
+        backup,
+        tags,
+    ):
         """Create a new EFS File System Volume.
 
         https://docs.aws.amazon.com/efs/latest/ug/API_CreateFileSystem.html
@@ -363,12 +421,22 @@ class EFSBackend(BaseBackend):
             self.region_name,
             creation_token,
             fsid,
-            **{k: v for k, v in params.items() if v is not None}
+            context=self,
+            performance_mode=performance_mode,
+            encrypted=encrypted,
+            kms_key_id=kms_key_id,
+            throughput_mode=throughput_mode,
+            provisioned_throughput_in_mibps=provisioned_throughput_in_mibps,
+            availability_zone_name=availability_zone_name,
+            backup=backup,
         )
+        self.tag_resource(fsid, tags)
         self.creation_tokens.add(creation_token)
         return self.file_systems_by_id[fsid]
 
-    def describe_file_systems(self, marker, max_items, creation_token, file_system_id):
+    def describe_file_systems(
+        self, marker=None, max_items=10, creation_token=None, file_system_id=None
+    ):
         """Describe all the EFS File Systems, or specific File Systems.
 
         https://docs.aws.amazon.com/efs/latest/ug/API_DescribeFileSystems.html
@@ -383,7 +451,7 @@ class EFSBackend(BaseBackend):
             corpus = []
             for fs in self.file_systems_by_id.values():
                 if fs.creation_token == creation_token:
-                    corpus.append(fs.info_json())
+                    corpus.append(fs)
         elif file_system_id:
             # Handle the case that a file_system_id is given.
             if file_system_id not in self.file_systems_by_id:
@@ -396,7 +464,7 @@ class EFSBackend(BaseBackend):
             corpus = self.next_markers[marker]
         else:
             # Handle the vanilla case.
-            corpus = [fs.info_json() for fs in self.file_systems_by_id.values()]
+            corpus = [fs for fs in self.file_systems_by_id.values()]
 
         # Handle the max_items parameter.
         file_systems = corpus[:max_items]
@@ -445,42 +513,40 @@ class EFSBackend(BaseBackend):
     def describe_mount_targets(
         self, max_items, file_system_id, mount_target_id, access_point_id, marker
     ):
-        """Describe the mount targets given a mount target ID or a file system ID.
-
-        Note that as of this writing access points, and thus access point IDs are not
-        supported.
+        """Describe the mount targets given an access point ID, mount target ID or a file system ID.
 
         https://docs.aws.amazon.com/efs/latest/ug/API_DescribeMountTargets.html
         """
         # Restrict the possible corpus of results based on inputs.
         if not (bool(file_system_id) ^ bool(mount_target_id) ^ bool(access_point_id)):
             raise BadRequest("Must specify exactly one mutually exclusive parameter.")
-        elif file_system_id:
+
+        if access_point_id:
+            file_system_id = self.access_points[access_point_id].file_system_id
+
+        if file_system_id:
             # Handle the case that a file_system_id is given.
             if file_system_id not in self.file_systems_by_id:
                 raise FileSystemNotFound(file_system_id)
             corpus = [
-                mt.info_json()
+                mt
                 for mt in self.file_systems_by_id[file_system_id].iter_mount_targets()
             ]
         elif mount_target_id:
             if mount_target_id not in self.mount_targets_by_id:
                 raise MountTargetNotFound(mount_target_id)
             # Handle mount target specification case.
-            corpus = [self.mount_targets_by_id[mount_target_id].info_json()]
-        else:
-            # We don't handle access_point_id's yet.
-            assert False, "Moto does not yet support EFS access points."
+            corpus = [self.mount_targets_by_id[mount_target_id]]
 
         # Handle the case that a marker is given. Note that the handling is quite
         # different from that in describe_file_systems.
         if marker is not None:
             if marker not in self.next_markers:
                 raise BadRequest("Invalid Marker")
-            corpus_mtids = {m["MountTargetId"] for m in corpus}
-            marked_mtids = {m["MountTargetId"] for m in self.next_markers[marker]}
+            corpus_mtids = {m.mount_target_id for m in corpus}
+            marked_mtids = {m.mount_target_id for m in self.next_markers[marker]}
             mt_ids = corpus_mtids & marked_mtids
-            corpus = [self.mount_targets_by_id[mt_id].info_json() for mt_id in mt_ids]
+            corpus = [self.mount_targets_by_id[mt_id] for mt_id in mt_ids]
 
         # Handle the max_items parameter.
         mount_targets = corpus[:max_items]
@@ -529,5 +595,72 @@ class EFSBackend(BaseBackend):
             raise PolicyNotFound("None")
         return backup_policy
 
+    def put_lifecycle_configuration(self, file_system_id, policies):
+        _, fss = self.describe_file_systems(file_system_id=file_system_id)
+        file_system = fss[0]
+        file_system.lifecycle_policies = policies
+
+    def describe_lifecycle_configuration(self, file_system_id):
+        _, fss = self.describe_file_systems(file_system_id=file_system_id)
+        file_system = fss[0]
+        return file_system.lifecycle_policies
+
+    def describe_mount_target_security_groups(self, mount_target_id):
+        if mount_target_id not in self.mount_targets_by_id:
+            raise MountTargetNotFound(mount_target_id)
+
+        mount_target = self.mount_targets_by_id[mount_target_id]
+        return mount_target.security_groups
+
+    def modify_mount_target_security_groups(self, mount_target_id, security_groups):
+        if mount_target_id not in self.mount_targets_by_id:
+            raise MountTargetNotFound(mount_target_id)
+
+        mount_target = self.mount_targets_by_id[mount_target_id]
+        mount_target.security_groups = security_groups
+
+        self.ec2_backend.modify_network_interface_attribute(
+            eni_id=mount_target.network_interface_id, group_ids=security_groups
+        )
+
+    def create_access_point(
+        self, client_token, tags, file_system_id, posix_user, root_directory
+    ):
+        name = next((tag["Value"] for tag in tags if tag["Key"] == "Name"), None)
+        access_point = AccessPoint(
+            self.region_name,
+            client_token,
+            file_system_id,
+            name,
+            posix_user,
+            root_directory,
+            context=self,
+        )
+        self.tagging_service.tag_resource(access_point.access_point_id, tags)
+        self.access_points[access_point.access_point_id] = access_point
+        return access_point
+
+    def describe_access_points(self, access_point_id):
+        """
+        Pagination is not yet implemented
+        """
+        if access_point_id:
+            if access_point_id not in self.access_points:
+                raise AccessPointNotFound(access_point_id)
+            return [self.access_points[access_point_id]]
+        return self.access_points.values()
+
+    def delete_access_point(self, access_point_id):
+        self.access_points.pop(access_point_id, None)
+
+    def list_tags_for_resource(self, resource_id):
+        return self.tagging_service.list_tags_for_resource(resource_id)["Tags"]
+
+    def tag_resource(self, resource_id, tags):
+        self.tagging_service.tag_resource(resource_id, tags)
+
+    def untag_resource(self, resource_id, tag_keys):
+        self.tagging_service.untag_resource_using_names(resource_id, tag_keys)
+
 
 efs_backends = BackendDict(EFSBackend, "efs")
