@@ -4,6 +4,9 @@ from moto.core.exceptions import RESTError
 class ELBClientError(RESTError):
     code = 400
 
+    def __init__(self, error_type, message):
+        super().__init__(error_type, message, template="wrapped_single_error")
+
 
 class DuplicateTagKeysError(ELBClientError):
     def __init__(self, cidr):
@@ -27,6 +30,13 @@ class LoadBalancerNotFoundError(ELBClientError):
         )
 
 
+class PolicyNotFoundError(ELBClientError):
+    def __init__(self):
+        super().__init__(
+            "PolicyNotFound", "There is no policy with name . for load balancer ."
+        )
+
+
 class TooManyTagsError(ELBClientError):
     def __init__(self):
         super().__init__(
