@@ -11,6 +11,7 @@ from moto.core.utils import (
     BackendDict,
 )
 from moto.ec2.models import ec2_backends
+from moto.utilities.tagging_service import TaggingService
 from .utils import make_arn_for_target_group
 from .utils import make_arn_for_load_balancer
 from .exceptions import (
@@ -38,6 +39,14 @@ from .exceptions import (
     InvalidLoadBalancerActionException,
 )
 
+ALLOWED_ACTIONS = [
+    "redirect",
+    "authenticate-cognito",
+    "authenticate-oidc",
+    "fixed-response",
+    "forward",
+]
+
 
 class FakeHealthStatus(BaseModel):
     def __init__(
@@ -73,7 +82,6 @@ class FakeTargetGroup(CloudFormationModel):
         matcher=None,
         target_type=None,
     ):
-
         # TODO: default values differs when you add Network Load balancer
         self.name = name
         self.arn = arn
@@ -85,15 +93,21 @@ class FakeTargetGroup(CloudFormationModel):
         self.healthcheck_port = healthcheck_port
         self.healthcheck_path = healthcheck_path
         self.healthcheck_interval_seconds = healthcheck_interval_seconds or 30
-        self.healthcheck_timeout_seconds = healthcheck_timeout_seconds or 5
+        self.healthcheck_timeout_seconds = healthcheck_timeout_seconds
+        if not healthcheck_timeout_seconds:
+            # Default depends on protocol
+            if protocol in ["TCP", "TLS"]:
+                self.healthcheck_timeout_seconds = 6
+            elif protocol in ["HTTP", "HTTPS", "GENEVE"]:
+                self.healthcheck_timeout_seconds = 5
+            else:
+                self.healthcheck_timeout_seconds = 30
         self.healthcheck_enabled = healthcheck_enabled
         self.healthy_threshold_count = healthy_threshold_count or 5
         self.unhealthy_threshold_count = unhealthy_threshold_count or 2
         self.load_balancer_arns = []
-        self.tags = {}
-        self.matcher = matcher
-        if self.protocol != "TCP":
-            self.matcher = self.matcher or {"HttpCode": "200"}
+        if self.healthcheck_protocol != "TCP":
+            self.matcher = matcher or {"HttpCode": "200"}
             self.healthcheck_path = self.healthcheck_path or "/"
             self.healthcheck_port = self.healthcheck_port or str(self.port)
         self.target_type = target_type
@@ -101,6 +115,9 @@ class FakeTargetGroup(CloudFormationModel):
         self.attributes = {
             "deregistration_delay.timeout_seconds": 300,
             "stickiness.enabled": "false",
+            "load_balancing.algorithm.type": "round_robin",
+            "slow_start.duration_seconds": 0,
+            "waf.fail_open.enabled": "false",
         }
 
         self.targets = OrderedDict()
@@ -127,11 +144,6 @@ class FakeTargetGroup(CloudFormationModel):
             if target_id in instance_ids:
                 del self.targets[target_id]
 
-    def add_tag(self, key, value):
-        if len(self.tags) >= 10 and key not in self.tags:
-            raise TooManyTagsError()
-        self.tags[key] = value
-
     def health_for(self, target, ec2_backend):
         t = self.targets.get(target["id"])
         if t is None:
@@ -207,6 +219,7 @@ class FakeListener(CloudFormationModel):
         ssl_policy,
         certificate,
         default_actions,
+        alpn_policy,
     ):
         self.load_balancer_arn = load_balancer_arn
         self.arn = arn
@@ -216,6 +229,7 @@ class FakeListener(CloudFormationModel):
         self.certificate = certificate
         self.certificates = [certificate] if certificate is not None else []
         self.default_actions = default_actions
+        self.alpn_policy = alpn_policy or []
         self._non_default_rules = OrderedDict()
         self._default_rule = OrderedDict()
         self._default_rule[0] = FakeRule(
@@ -225,7 +239,6 @@ class FakeListener(CloudFormationModel):
             actions=default_actions,
             is_default=True,
         )
-        self.tags = {}
 
     @property
     def physical_resource_id(self):
@@ -299,9 +312,7 @@ class FakeListener(CloudFormationModel):
 
 
 class FakeListenerRule(CloudFormationModel):
-    def __init__(
-        self, listener_arn, arn, conditions, priority, actions,
-    ):
+    def __init__(self, listener_arn, arn, conditions, priority, actions):
         self.listener_arn = listener_arn
         self.arn = arn
         self.conditions = conditions
@@ -367,9 +378,18 @@ class FakeAction(BaseModel):
         self.data = data
         self.type = data.get("Type")
 
+        if "ForwardConfig" in self.data:
+            if "TargetGroupStickinessConfig" not in self.data["ForwardConfig"]:
+                self.data["ForwardConfig"]["TargetGroupStickinessConfig"] = {
+                    "Enabled": "false"
+                }
+
     def to_xml(self):
         template = Template(
             """<Type>{{ action.type }}</Type>
+            {% if "Order" in action.data %}
+            <Order>{{ action.data["Order"] }}</Order>
+            {% endif %}
             {% if action.type == "forward" and "ForwardConfig" in action.data %}
             <ForwardConfig>
               <TargetGroups>
@@ -380,6 +400,12 @@ class FakeAction(BaseModel):
                 </member>
                 {% endfor %}
               </TargetGroups>
+              <TargetGroupStickinessConfig>
+                  <Enabled>{{ action.data["ForwardConfig"]["TargetGroupStickinessConfig"]["Enabled"] }}</Enabled>
+                  {% if "DurationSeconds" in action.data["ForwardConfig"]["TargetGroupStickinessConfig"] %}
+                  <DurationSeconds>{{ action.data["ForwardConfig"]["TargetGroupStickinessConfig"]["DurationSeconds"] }}</DurationSeconds>
+                  {% endif %}
+              </TargetGroupStickinessConfig>
             </ForwardConfig>
             {% endif %}
             {% if action.type == "forward" and "ForwardConfig" not in action.data %}
@@ -389,13 +415,71 @@ class FakeAction(BaseModel):
                 <Protocol>{{ action.data["RedirectConfig"]["Protocol"] }}</Protocol>
                 <Port>{{ action.data["RedirectConfig"]["Port"] }}</Port>
                 <StatusCode>{{ action.data["RedirectConfig"]["StatusCode"] }}</StatusCode>
+                {% if action.data["RedirectConfig"]["Host"] %}<Host>{{ action.data["RedirectConfig"]["Host"] }}</Host>{% endif %}
+                {% if action.data["RedirectConfig"]["Path"] %}<Path>{{ action.data["RedirectConfig"]["Path"] }}</Path>{% endif %}
+                {% if action.data["RedirectConfig"]["Query"] %}<Query>{{ action.data["RedirectConfig"]["Query"] }}</Query>{% endif %}
             </RedirectConfig>
             {% elif action.type == "authenticate-cognito" %}
             <AuthenticateCognitoConfig>
                 <UserPoolArn>{{ action.data["AuthenticateCognitoConfig"]["UserPoolArn"] }}</UserPoolArn>
                 <UserPoolClientId>{{ action.data["AuthenticateCognitoConfig"]["UserPoolClientId"] }}</UserPoolClientId>
                 <UserPoolDomain>{{ action.data["AuthenticateCognitoConfig"]["UserPoolDomain"] }}</UserPoolDomain>
+                {% if "SessionCookieName" in action.data["AuthenticateCognitoConfig"] %}
+                <SessionCookieName>{{ action.data["AuthenticateCognitoConfig"]["SessionCookieName"] }}</SessionCookieName>
+                {% endif %}
+                {% if "Scope" in action.data["AuthenticateCognitoConfig"] %}
+                <Scope>{{ action.data["AuthenticateCognitoConfig"]["Scope"] }}</Scope>
+                {% endif %}
+                {% if "SessionTimeout" in action.data["AuthenticateCognitoConfig"] %}
+                <SessionTimeout>{{ action.data["AuthenticateCognitoConfig"]["SessionTimeout"] }}</SessionTimeout>
+                {% endif %}
+                {% if action.data["AuthenticateCognitoConfig"].get("AuthenticationRequestExtraParams") %}
+                <AuthenticationRequestExtraParams>
+                    {% for entry in action.data["AuthenticateCognitoConfig"].get("AuthenticationRequestExtraParams", {}).get("entry", {}).values() %}
+                    <member>
+                        <key>{{ entry["key"] }}</key>
+                        <value>{{ entry["value"] }}</value>
+                    </member>
+                    {% endfor %}
+                </AuthenticationRequestExtraParams>
+                {% endif %}
+                {% if "OnUnauthenticatedRequest" in action.data["AuthenticateCognitoConfig"] %}
+                <OnUnauthenticatedRequest>{{ action.data["AuthenticateCognitoConfig"]["OnUnauthenticatedRequest"] }}</OnUnauthenticatedRequest>
+                {% endif %}
             </AuthenticateCognitoConfig>
+            {% elif action.type == "authenticate-oidc" %}
+            <AuthenticateOidcConfig>
+              <AuthorizationEndpoint>{{ action.data["AuthenticateOidcConfig"]["AuthorizationEndpoint"] }}</AuthorizationEndpoint>
+              <ClientId>{{ action.data["AuthenticateOidcConfig"]["ClientId"] }}</ClientId>
+              {% if "ClientSecret" in action.data["AuthenticateOidcConfig"] %}
+              <ClientSecret>{{ action.data["AuthenticateOidcConfig"]["ClientSecret"] }}</ClientSecret>
+              {% endif %}
+              <Issuer>{{ action.data["AuthenticateOidcConfig"]["Issuer"] }}</Issuer>
+              <TokenEndpoint>{{ action.data["AuthenticateOidcConfig"]["TokenEndpoint"] }}</TokenEndpoint>
+              <UserInfoEndpoint>{{ action.data["AuthenticateOidcConfig"]["UserInfoEndpoint"] }}</UserInfoEndpoint>
+              {% if "OnUnauthenticatedRequest" in action.data["AuthenticateOidcConfig"] %}
+              <OnUnauthenticatedRequest>{{ action.data["AuthenticateOidcConfig"]["OnUnauthenticatedRequest"] }}</OnUnauthenticatedRequest>
+              {% endif %}
+              {% if "UseExistingClientSecret" in action.data["AuthenticateOidcConfig"] %}
+              <UseExistingClientSecret>{{ action.data["AuthenticateOidcConfig"]["UseExistingClientSecret"] }}</UseExistingClientSecret>
+              {% endif %}
+              {% if "SessionTimeout" in action.data["AuthenticateOidcConfig"] %}
+              <SessionTimeout>{{ action.data["AuthenticateOidcConfig"]["SessionTimeout"] }}</SessionTimeout>
+              {% endif %}
+              {% if "SessionCookieName" in action.data["AuthenticateOidcConfig"] %}
+              <SessionCookieName>{{ action.data["AuthenticateOidcConfig"]["SessionCookieName"] }}</SessionCookieName>
+              {% endif %}
+              {% if "Scope" in action.data["AuthenticateOidcConfig"] %}
+              <Scope>{{ action.data["AuthenticateOidcConfig"]["Scope"] }}</Scope>
+              {% endif %}
+              {% if action.data["AuthenticateOidcConfig"].get("AuthenticationRequestExtraParams") %}
+              <AuthenticationRequestExtraParams>
+                  {% for entry in action.data["AuthenticateOidcConfig"].get("AuthenticationRequestExtraParams", {}).get("entry", {}).values() %}
+                  <member><key>{{ entry["key"] }}</key><value>{{ entry["value"] }}</value></member>
+                  {% endfor %}
+              </AuthenticationRequestExtraParams>
+              {% endif %}
+            </AuthenticateOidcConfig>
             {% elif action.type == "fixed-response" %}
              <FixedResponseConfig>
                 <ContentType>{{ action.data["FixedResponseConfig"]["ContentType"] }}</ContentType>
@@ -427,9 +511,14 @@ class FakeLoadBalancer(CloudFormationModel):
         "access_logs.s3.prefix",
         "deletion_protection.enabled",
         "idle_timeout.timeout_seconds",
+        "ipv6.deny_all_igw_traffic",
         "load_balancing.cross_zone.enabled",
-        "routing.http2.enabled",
+        "routing.http.desync_mitigation_mode",
         "routing.http.drop_invalid_header_fields.enabled",
+        "routing.http.x_amzn_tls_version_and_cipher_suite.enabled",
+        "routing.http.xff_client_port.enabled",
+        "routing.http2.enabled",
+        "waf.fail_open.enabled",
     }
 
     def __init__(
@@ -470,18 +559,6 @@ class FakeLoadBalancer(CloudFormationModel):
     def physical_resource_id(self):
         return self.arn
 
-    def add_tag(self, key, value):
-        if len(self.tags) >= 10 and key not in self.tags:
-            raise TooManyTagsError()
-        self.tags[key] = value
-
-    def list_tags(self):
-        return self.tags
-
-    def remove_tag(self, key):
-        if key in self.tags:
-            del self.tags[key]
-
     def activate(self):
         if self.state == "provisioning":
             self.state = "active"
@@ -517,8 +594,8 @@ class FakeLoadBalancer(CloudFormationModel):
         return load_balancer
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in [
+    def has_cfn_attr(cls, attr):
+        return attr in [
             "DNSName",
             "LoadBalancerName",
             "CanonicalHostedZoneID",
@@ -563,6 +640,7 @@ class ELBv2Backend(BaseBackend):
         self.region_name = region_name
         self.target_groups = OrderedDict()
         self.load_balancers = OrderedDict()
+        self.tagging_service = TaggingService()
 
     @staticmethod
     def default_vpc_endpoint_service(service_region, zones):
@@ -591,20 +669,28 @@ class ELBv2Backend(BaseBackend):
         name,
         security_groups,
         subnet_ids,
+        subnet_mappings=None,
         scheme="internet-facing",
         loadbalancer_type=None,
+        tags=None,
     ):
         vpc_id = None
         subnets = []
         state = "provisioning"
 
-        if not subnet_ids:
+        if not subnet_ids and not subnet_mappings:
             raise SubnetNotFoundError()
         for subnet_id in subnet_ids:
             subnet = self.ec2_backend.get_subnet(subnet_id)
             if subnet is None:
                 raise SubnetNotFoundError()
             subnets.append(subnet)
+        for subnet in subnet_mappings or []:
+            subnet_id = subnet["SubnetId"]
+            subnet = self.ec2_backend.get_subnet(subnet_id)
+            if subnet is None:
+                raise SubnetNotFoundError()
+            subnets.append(subnet)
 
         vpc_id = subnets[0].vpc_id
         arn = make_arn_for_load_balancer(
@@ -627,6 +713,7 @@ class ELBv2Backend(BaseBackend):
             loadbalancer_type=loadbalancer_type,
         )
         self.load_balancers[arn] = new_load_balancer
+        self.tagging_service.tag_resource(arn, tags)
         return new_load_balancer
 
     def convert_and_validate_action_properties(self, properties):
@@ -635,18 +722,13 @@ class ELBv2Backend(BaseBackend):
         default_actions = []
         for i, action in enumerate(properties["Actions"]):
             action_type = action["Type"]
-            if action_type in [
-                "redirect",
-                "authenticate-cognito",
-                "fixed-response",
-                "forward",
-            ]:
+            if action_type in ALLOWED_ACTIONS:
                 default_actions.append(action)
             else:
                 raise InvalidActionTypeError(action_type, i + 1)
         return default_actions
 
-    def create_rule(self, listener_arn, conditions, priority, actions):
+    def create_rule(self, listener_arn, conditions, priority, actions, tags=None):
         actions = [FakeAction(action) for action in actions]
         listeners = self.describe_listeners(None, [listener_arn])
         if not listeners:
@@ -676,8 +758,9 @@ class ELBv2Backend(BaseBackend):
         # TODO: check for error 'TooManyRules'
 
         # create rule
-        rule = FakeListenerRule(listener.arn, arn, conditions, priority, actions,)
+        rule = FakeListenerRule(listener.arn, arn, conditions, priority, actions)
         listener.register(arn, rule)
+        self.tagging_service.tag_resource(arn, tags)
         return rule
 
     def _validate_conditions(self, conditions):
@@ -840,7 +923,11 @@ class ELBv2Backend(BaseBackend):
                         raise ActionTargetGroupNotFoundError(target_group_arn)
             elif action_type == "fixed-response":
                 self._validate_fixed_response_action(action, i, index)
-            elif action_type in ["redirect", "authenticate-cognito"]:
+            elif action_type in [
+                "redirect",
+                "authenticate-cognito",
+                "authenticate-oidc",
+            ]:
                 pass
             # pass if listener rule has forward_config as an Action property
             elif action_type == "forward" and "ForwardConfig" in action.data.keys():
@@ -925,6 +1012,7 @@ Member must satisfy regular expression pattern: {}".format(
 
         if (
             kwargs.get("matcher")
+            and kwargs["matcher"].get("HttpCode")
             and FakeTargetGroup.HTTP_CODE_REGEX.match(kwargs["matcher"]["HttpCode"])
             is None
         ):
@@ -936,8 +1024,11 @@ Member must satisfy regular expression pattern: {}".format(
         arn = make_arn_for_target_group(
             account_id=ACCOUNT_ID, name=name, region_name=self.region_name
         )
+        tags = kwargs.pop("tags", None)
         target_group = FakeTargetGroup(name, arn, **kwargs)
         self.target_groups[target_group.arn] = target_group
+        if tags:
+            self.add_tags(resource_arns=[target_group.arn], tags=tags)
         return target_group
 
     def modify_target_group_attributes(self, target_group_arn, attributes):
@@ -966,11 +1057,7 @@ Member must satisfy regular expression pattern: {}".format(
                 default_actions.append(
                     {"Type": action_type, "TargetGroupArn": action["TargetGroupArn"]}
                 )
-            elif action_type in [
-                "redirect",
-                "authenticate-cognito",
-                "fixed-response",
-            ]:
+            elif action_type in ALLOWED_ACTIONS:
                 default_actions.append(action)
             else:
                 raise InvalidActionTypeError(action_type, i + 1)
@@ -984,6 +1071,8 @@ Member must satisfy regular expression pattern: {}".format(
         ssl_policy,
         certificate,
         default_actions,
+        alpn_policy=None,
+        tags=None,
     ):
         default_actions = [FakeAction(action) for action in default_actions]
         balancer = self.load_balancers.get(load_balancer_arn)
@@ -1006,6 +1095,7 @@ Member must satisfy regular expression pattern: {}".format(
             ssl_policy,
             certificate,
             default_actions,
+            alpn_policy,
         )
         balancer.listeners[listener.arn] = listener
         for action in default_actions:
@@ -1015,6 +1105,8 @@ Member must satisfy regular expression pattern: {}".format(
                     target_group = self.target_groups[arn]
                     target_group.load_balancer_arns.append(load_balancer_arn)
 
+        self.tagging_service.tag_resource(listener.arn, tags)
+
         return listener
 
     def describe_load_balancers(self, arns, names):
@@ -1072,6 +1164,8 @@ Member must satisfy regular expression pattern: {}".format(
                 for rule in listener.rules.values():
                     if rule.arn in rule_arns:
                         matched_rules.append(rule)
+        if len(matched_rules) != len(rule_arns):
+            raise RuleNotFoundError("One or more rules not found")
         return matched_rules
 
     def describe_target_groups(self, load_balancer_arn, target_group_arns, names):
@@ -1275,7 +1369,7 @@ Member must satisfy regular expression pattern: {}".format(
 
         balancer.security_groups = sec_groups
 
-    def set_subnets(self, arn, subnets):
+    def set_subnets(self, arn, subnets, subnet_mappings):
         balancer = self.load_balancers.get(arn)
         if balancer is None:
             raise LoadBalancerNotFoundError()
@@ -1284,19 +1378,20 @@ Member must satisfy regular expression pattern: {}".format(
         sub_zone_list = {}
         for subnet in subnets:
             try:
-                subnet = self.ec2_backend.get_subnet(subnet)
-
-                if subnet.availability_zone in sub_zone_list:
-                    raise RESTError(
-                        "InvalidConfigurationRequest",
-                        "More than 1 subnet cannot be specified for 1 availability zone",
-                    )
+                subnet = self._get_subnet(sub_zone_list, subnet)
 
                 sub_zone_list[subnet.availability_zone] = subnet.id
                 subnet_objects.append(subnet)
             except Exception:
                 raise SubnetNotFoundError()
 
+        for subnet_mapping in subnet_mappings:
+            subnet_id = subnet_mapping["SubnetId"]
+            subnet = self._get_subnet(sub_zone_list, subnet_id)
+
+            sub_zone_list[subnet.availability_zone] = subnet.id
+            subnet_objects.append(subnet)
+
         if len(sub_zone_list) < 2:
             raise RESTError(
                 "InvalidConfigurationRequest",
@@ -1307,6 +1402,15 @@ Member must satisfy regular expression pattern: {}".format(
 
         return sub_zone_list.items()
 
+    def _get_subnet(self, sub_zone_list, subnet):
+        subnet = self.ec2_backend.get_subnet(subnet)
+        if subnet.availability_zone in sub_zone_list:
+            raise RESTError(
+                "InvalidConfigurationRequest",
+                "More than 1 subnet cannot be specified for 1 availability zone",
+            )
+        return subnet
+
     def modify_load_balancer_attributes(self, arn, attrs):
         balancer = self.load_balancers.get(arn)
         if balancer is None:
@@ -1385,20 +1489,16 @@ Member must satisfy regular expression pattern: {}".format(
         default_actions=None,
     ):
         default_actions = [FakeAction(action) for action in default_actions]
-        for load_balancer in self.load_balancers.values():
-            if arn in load_balancer.listeners:
-                break
-        else:
-            raise ListenerNotFoundError()
-
-        listener = load_balancer.listeners[arn]
+        listener = self.describe_listeners(load_balancer_arn=None, listener_arns=[arn])[
+            0
+        ]
 
         if port is not None:
             listener.port = port
 
         if protocol not in (None, "HTTP", "HTTPS", "TCP"):
             raise RESTError(
-                "UnsupportedProtocol", "Protocol {0} is not supported".format(protocol),
+                "UnsupportedProtocol", "Protocol {0} is not supported".format(protocol)
             )
 
         # HTTPS checks
@@ -1416,11 +1516,13 @@ Member must satisfy regular expression pattern: {}".format(
                     )
                 listener.certificate = default_cert_arn
                 listener.certificates = certificates
-            else:
+            elif len(certificates) == 0 and len(listener.certificates) == 0:
                 raise RESTError(
                     "CertificateWereNotPassed",
                     "You must provide a list containing exactly one certificate if the listener protocol is HTTPS.",
                 )
+            # else:
+            # The list was not provided, meaning we just keep the existing certificates (if any)
 
         if protocol is not None:
             listener.protocol = protocol
@@ -1476,5 +1578,78 @@ Member must satisfy regular expression pattern: {}".format(
         for target_group in self.target_groups.values():
             target_group.deregister_terminated_instances(instance_ids)
 
+    def add_listener_certificates(self, arn, certificates):
+        listener = self.describe_listeners(load_balancer_arn=None, listener_arns=[arn])[
+            0
+        ]
+        listener.certificates.extend([c["certificate_arn"] for c in certificates])
+        return listener.certificates
+
+    def describe_listener_certificates(self, arn):
+        listener = self.describe_listeners(load_balancer_arn=None, listener_arns=[arn])[
+            0
+        ]
+        return listener.certificates
+
+    def remove_listener_certificates(self, arn, certificates):
+        listener = self.describe_listeners(load_balancer_arn=None, listener_arns=[arn])[
+            0
+        ]
+        cert_arns = [c["certificate_arn"] for c in certificates]
+        listener.certificates = [c for c in listener.certificates if c not in cert_arns]
+
+    def add_tags(self, resource_arns, tags):
+        tag_dict = self.tagging_service.flatten_tag_list(tags)
+        for arn in resource_arns:
+            existing = self.tagging_service.get_tag_dict_for_resource(arn)
+            for key in tag_dict:
+                if len(existing) >= 10 and key not in existing:
+                    raise TooManyTagsError()
+            self._get_resource_by_arn(arn)
+            self.tagging_service.tag_resource(arn, tags)
+
+    def remove_tags(self, resource_arns, tag_keys):
+        for arn in resource_arns:
+            self.tagging_service.untag_resource_using_names(arn, tag_keys)
+
+    def describe_tags(self, resource_arns):
+        return {
+            arn: self.tagging_service.get_tag_dict_for_resource(arn)
+            for arn in resource_arns
+        }
+
+    def _get_resource_by_arn(self, arn):
+        if ":targetgroup" in arn:
+            resource = self.target_groups.get(arn)
+            if not resource:
+                raise TargetGroupNotFoundError()
+        elif ":loadbalancer" in arn:
+            resource = self.load_balancers.get(arn)
+            if not resource:
+                raise LoadBalancerNotFoundError()
+        elif ":listener-rule" in arn:
+            lb_arn = arn.replace(":listener-rule", ":loadbalancer").rsplit("/", 2)[0]
+            balancer = self.load_balancers.get(lb_arn)
+            if not balancer:
+                raise LoadBalancerNotFoundError()
+            listener_arn = arn.replace(":listener-rule", ":listener").rsplit("/", 1)[0]
+            listener = balancer.listeners.get(listener_arn)
+            if not listener:
+                raise ListenerNotFoundError()
+            resource = listener.rules.get(arn)
+            if not resource:
+                raise RuleNotFoundError()
+        elif ":listener" in arn:
+            lb_arn, _, _ = arn.replace(":listener", ":loadbalancer").rpartition("/")
+            balancer = self.load_balancers.get(lb_arn)
+            if not balancer:
+                raise LoadBalancerNotFoundError()
+            resource = balancer.listeners.get(arn)
+            if not resource:
+                raise ListenerNotFoundError()
+        else:
+            raise LoadBalancerNotFoundError()
+        return resource
+
 
 elbv2_backends = BackendDict(ELBv2Backend, "ec2")
