@@ -532,7 +532,7 @@ class ElasticMapReduceResponse(BaseResponse):
     def remove_auto_scaling_policy(self):
         cluster_id = self._get_param("ClusterId")
         instance_group_id = self._get_param("InstanceGroupId")
-        instance_group = self.backend.put_auto_scaling_policy(instance_group_id, None)
+        instance_group = self.backend.remove_auto_scaling_policy(instance_group_id)
         template = self.response_template(REMOVE_AUTO_SCALING_POLICY)
         return template.render(cluster_id=cluster_id, instance_group=instance_group)
 
