@@ -70,11 +70,13 @@ class Rule(CloudFormationModel):
             else "{}/".format(self.event_bus_name)
         )
 
-        return "arn:aws:events:{region}:{account_id}:rule/{event_bus_name}{name}".format(
-            region=self.region_name,
-            account_id=ACCOUNT_ID,
-            event_bus_name=event_bus_name,
-            name=self.name,
+        return (
+            "arn:aws:events:{region}:{account_id}:rule/{event_bus_name}{name}".format(
+                region=self.region_name,
+                account_id=ACCOUNT_ID,
+                event_bus_name=event_bus_name,
+                name=self.name,
+            )
         )
 
     @property
@@ -186,7 +188,7 @@ class Rule(CloudFormationModel):
 
         logs_backends[self.region_name].create_log_stream(name, log_stream_name)
         logs_backends[self.region_name].put_log_events(
-            name, log_stream_name, log_events, None
+            name, log_stream_name, log_events
         )
 
     def _send_to_events_archive(self, resource_id, event):
@@ -221,8 +223,8 @@ class Rule(CloudFormationModel):
         )
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["Arn"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["Arn"]
 
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
@@ -340,8 +342,8 @@ class EventBus(CloudFormationModel):
         event_backend.delete_event_bus(name=self.name)
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["Arn", "Name", "Policy"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["Arn", "Name", "Policy"]
 
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
@@ -542,8 +544,8 @@ class Archive(CloudFormationModel):
         event_backend.archives.pop(self.name)
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["Arn", "ArchiveName"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["Arn", "ArchiveName"]
 
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
@@ -679,7 +681,7 @@ class Replay(BaseModel):
 
 class Connection(BaseModel):
     def __init__(
-        self, name, region_name, description, authorization_type, auth_parameters,
+        self, name, region_name, description, authorization_type, auth_parameters
     ):
         self.uuid = uuid4()
         self.name = name
@@ -1043,7 +1045,11 @@ class EventsBackend(BaseBackend):
         return rule
 
     def delete_rule(self, name):
-        arn = self.rules.get(name).arn
+        rule = self.rules.get(name)
+        if len(rule.targets) > 0:
+            raise ValidationException("Rule can't be deleted since it has targets.")
+
+        arn = rule.arn
         if self.tagger.has_tags(arn):
             self.tagger.delete_all_tags_for_resource(arn)
         return self.rules.pop(name) is not None
