@@ -15,7 +15,10 @@ from .exceptions import (
     PartitionAlreadyExistsException,
     PartitionNotFoundException,
     VersionNotFoundException,
+    JobNotFoundException,
+    ConcurrentRunsExceededException,
 )
+from .utils import PartitionFilter
 from ..utilities.paginator import paginate
 
 
@@ -33,6 +36,7 @@ class GlueBackend(BaseBackend):
         self.databases = OrderedDict()
         self.crawlers = OrderedDict()
         self.jobs = OrderedDict()
+        self.job_runs = OrderedDict()
 
     @staticmethod
     def default_vpc_endpoint_service(service_region, zones):
@@ -198,6 +202,20 @@ class GlueBackend(BaseBackend):
         )
         return name
 
+    def get_job(self, name):
+        try:
+            return self.jobs[name]
+        except KeyError:
+            raise JobNotFoundException(name)
+
+    def start_job_run(self, name):
+        job = self.get_job(name)
+        return job.start_job_run()
+
+    def get_job_run(self, name, run_id):
+        job = self.get_job(name)
+        return job.get_job_run(run_id)
+
     @paginate(pagination_model=PAGINATION_MODEL)
     def list_jobs(self):
         return [job for _, job in self.jobs.items()]
@@ -261,8 +279,19 @@ class FakeTable(BaseModel):
             raise PartitionAlreadyExistsException()
         self.partitions[str(partition.values)] = partition
 
-    def get_partitions(self):
-        return [p for str_part_values, p in self.partitions.items()]
+    def get_partitions(self, expression):
+        """See https://docs.aws.amazon.com/glue/latest/webapi/API_GetPartitions.html
+        for supported expressions.
+
+        Expression caveats:
+
+        - Column names must consist of UPPERCASE, lowercase, dots and underscores only.
+        - Nanosecond expressions on timestamp columns are rounded to microseconds.
+        - Literal dates and timestamps must be valid, i.e. no support for February 31st.
+        - LIKE expressions are converted to Python regexes, escaping special characters.
+          Only % and _ wildcards are supported, and SQL escaping using [] does not work.
+        """
+        return list(filter(PartitionFilter(expression, self), self.partitions.values()))
 
     def get_partition(self, values):
         try:
@@ -402,7 +431,7 @@ class FakeCrawler(BaseModel):
 
 class LastCrawlInfo(BaseModel):
     def __init__(
-        self, error_message, log_group, log_stream, message_prefix, start_time, status,
+        self, error_message, log_group, log_stream, message_prefix, start_time, status
     ):
         self.error_message = error_message
         self.log_group = log_group
@@ -457,6 +486,7 @@ class FakeJob:
         self.max_retries = max_retries
         self.allocated_capacity = allocated_capacity
         self.timeout = timeout
+        self.state = "READY"
         self.max_capacity = max_capacity
         self.security_configuration = security_configuration
         self.tags = tags
@@ -470,5 +500,94 @@ class FakeJob:
     def get_name(self):
         return self.name
 
+    def as_dict(self):
+        return {
+            "Name": self.name,
+            "Description": self.description,
+            "LogUri": self.log_uri,
+            "Role": self.role,
+            "CreatedOn": self.created_on.isoformat(),
+            "LastModifiedOn": self.last_modified_on.isoformat(),
+            "ExecutionProperty": self.execution_property,
+            "Command": self.command,
+            "DefaultArguments": self.default_arguments,
+            "NonOverridableArguments": self.non_overridable_arguments,
+            "Connections": self.connections,
+            "MaxRetries": self.max_retries,
+            "AllocatedCapacity": self.allocated_capacity,
+            "Timeout": self.timeout,
+            "MaxCapacity": self.max_capacity,
+            "WorkerType": self.worker_type,
+            "NumberOfWorkers": self.number_of_workers,
+            "SecurityConfiguration": self.security_configuration,
+            "NotificationProperty": self.notification_property,
+            "GlueVersion": self.glue_version,
+        }
+
+    def start_job_run(self):
+        if self.state == "RUNNING":
+            raise ConcurrentRunsExceededException(
+                f"Job with name {self.name} already running"
+            )
+        fake_job_run = FakeJobRun(job_name=self.name)
+        self.state = "RUNNING"
+        return fake_job_run.job_run_id
+
+    def get_job_run(self, run_id):
+        fake_job_run = FakeJobRun(job_name=self.name, job_run_id=run_id)
+        return fake_job_run
+
+
+class FakeJobRun:
+    def __init__(
+        self,
+        job_name: int,
+        job_run_id: str = "01",
+        arguments: dict = None,
+        allocated_capacity: int = None,
+        timeout: int = None,
+        worker_type: str = "Standard",
+    ):
+        self.job_name = job_name
+        self.job_run_id = job_run_id
+        self.arguments = arguments
+        self.allocated_capacity = allocated_capacity
+        self.timeout = timeout
+        self.worker_type = worker_type
+        self.started_on = datetime.utcnow()
+        self.modified_on = datetime.utcnow()
+        self.completed_on = datetime.utcnow()
+
+    def get_name(self):
+        return self.job_name
+
+    def as_dict(self):
+        return {
+            "Id": self.job_run_id,
+            "Attempt": 1,
+            "PreviousRunId": "01",
+            "TriggerName": "test_trigger",
+            "JobName": self.job_name,
+            "StartedOn": self.started_on.isoformat(),
+            "LastModifiedOn": self.modified_on.isoformat(),
+            "CompletedOn": self.completed_on.isoformat(),
+            "JobRunState": "SUCCEEDED",
+            "Arguments": self.arguments or {"runSpark": "spark -f test_file.py"},
+            "ErrorMessage": "",
+            "PredecessorRuns": [
+                {"JobName": "string", "RunId": "string"},
+            ],
+            "AllocatedCapacity": self.allocated_capacity or 123,
+            "ExecutionTime": 123,
+            "Timeout": self.timeout or 123,
+            "MaxCapacity": 123.0,
+            "WorkerType": self.worker_type,
+            "NumberOfWorkers": 123,
+            "SecurityConfiguration": "string",
+            "LogGroupName": "test/log",
+            "NotificationProperty": {"NotifyDelayAfter": 123},
+            "GlueVersion": "0.9",
+        }
+
 
 glue_backend = GlueBackend()
