@@ -129,13 +129,12 @@ class GlueResponse(BaseResponse):
     def get_partitions(self):
         database_name = self.parameters.get("DatabaseName")
         table_name = self.parameters.get("TableName")
-        if "Expression" in self.parameters:
-            raise NotImplementedError(
-                "Expression filtering in get_partitions is not implemented in moto"
-            )
+        expression = self.parameters.get("Expression")
         table = self.glue_backend.get_table(database_name, table_name)
 
-        return json.dumps({"Partitions": [p.as_dict() for p in table.get_partitions()]})
+        return json.dumps(
+            {"Partitions": [p.as_dict() for p in table.get_partitions(expression)]}
+        )
 
     def get_partition(self):
         database_name = self.parameters.get("DatabaseName")
@@ -366,6 +365,22 @@ class GlueResponse(BaseResponse):
         )
         return json.dumps(dict(Name=name))
 
+    def get_job(self):
+        name = self.parameters.get("JobName")
+        job = self.glue_backend.get_job(name)
+        return json.dumps({"Job": job.as_dict()})
+
+    def start_job_run(self):
+        name = self.parameters.get("JobName")
+        job_run_id = self.glue_backend.start_job_run(name)
+        return json.dumps(dict(JobRunId=job_run_id))
+
+    def get_job_run(self):
+        name = self.parameters.get("JobName")
+        run_id = self.parameters.get("RunId")
+        job_run = self.glue_backend.get_job_run(name, run_id)
+        return json.dumps({"JobRun": job_run.as_dict()})
+
     def list_jobs(self):
         next_token = self._get_param("NextToken")
         max_results = self._get_int_param("MaxResults")
