@@ -123,10 +123,12 @@ class AssumedRoleAccessKey(object):
 
     @property
     def arn(self):
-        return "arn:aws:sts::{account_id}:assumed-role/{role_name}/{session_name}".format(
-            account_id=ACCOUNT_ID,
-            role_name=self._owner_role_name,
-            session_name=self._session_name,
+        return (
+            "arn:aws:sts::{account_id}:assumed-role/{role_name}/{session_name}".format(
+                account_id=ACCOUNT_ID,
+                role_name=self._owner_role_name,
+                session_name=self._session_name,
+            )
         )
 
     def create_credentials(self):
