@@ -1,6 +1,9 @@
 from .responses import IoTDataPlaneResponse
 
-url_bases = [r"https?://data\.iot\.(.+)\.amazonaws.com"]
+url_bases = [
+    r"https?://data\.iot\.(.+)\.amazonaws.com",
+    r"https?://data-ats\.iot\.(.+)\.amazonaws.com",
+]
 
 
 response = IoTDataPlaneResponse()
