@@ -31,27 +31,17 @@ class KinesisVideoResponse(BaseResponse):
         stream_name = self._get_param("StreamName")
         stream_arn = self._get_param("StreamARN")
         stream_info = self.kinesisvideo_backend.describe_stream(
-            stream_name=stream_name, stream_arn=stream_arn,
+            stream_name=stream_name, stream_arn=stream_arn
         )
         return json.dumps(dict(StreamInfo=stream_info))
 
     def list_streams(self):
-        max_results = self._get_int_param("MaxResults")
-        next_token = self._get_param("NextToken")
-        stream_name_condition = self._get_param("StreamNameCondition")
-        stream_info_list, next_token = self.kinesisvideo_backend.list_streams(
-            max_results=max_results,
-            next_token=next_token,
-            stream_name_condition=stream_name_condition,
-        )
+        stream_info_list, next_token = self.kinesisvideo_backend.list_streams()
         return json.dumps(dict(StreamInfoList=stream_info_list, NextToken=next_token))
 
     def delete_stream(self):
         stream_arn = self._get_param("StreamARN")
-        current_version = self._get_param("CurrentVersion")
-        self.kinesisvideo_backend.delete_stream(
-            stream_arn=stream_arn, current_version=current_version,
-        )
+        self.kinesisvideo_backend.delete_stream(stream_arn=stream_arn)
         return json.dumps(dict())
 
     def get_data_endpoint(self):
@@ -59,6 +49,6 @@ class KinesisVideoResponse(BaseResponse):
         stream_arn = self._get_param("StreamARN")
         api_name = self._get_param("APIName")
         data_endpoint = self.kinesisvideo_backend.get_data_endpoint(
-            stream_name=stream_name, stream_arn=stream_arn, api_name=api_name,
+            stream_name=stream_name, stream_arn=stream_arn, api_name=api_name
         )
         return json.dumps(dict(DataEndpoint=data_endpoint))
