@@ -2,8 +2,7 @@ import uuid
 
 from datetime import datetime, timedelta
 
-from moto import core as moto_core
-from moto.core import BaseBackend, BaseModel
+from moto.core import ACCOUNT_ID, BaseBackend, BaseModel
 from moto.core.models import CloudFormationModel
 from moto.core.utils import unix_time_millis, BackendDict
 from moto.utilities.paginator import paginate
@@ -61,12 +60,7 @@ class LogStream(BaseModel):
 
     def __init__(self, region, log_group, name):
         self.region = region
-        self.arn = "arn:aws:logs:{region}:{id}:log-group:{log_group}:log-stream:{log_stream}".format(
-            region=region,
-            id=moto_core.ACCOUNT_ID,
-            log_group=log_group,
-            log_stream=name,
-        )
+        self.arn = f"arn:aws:logs:{region}:{ACCOUNT_ID}:log-group:{log_group}:log-stream:{name}"
         self.creation_time = int(unix_time_millis())
         self.first_event_timestamp = None
         self.last_event_timestamp = None
@@ -111,9 +105,7 @@ class LogStream(BaseModel):
             res.update(rest)
         return res
 
-    def put_log_events(
-        self, log_group_name, log_stream_name, log_events, sequence_token
-    ):
+    def put_log_events(self, log_group_name, log_stream_name, log_events):
         # TODO: ensure sequence_token
         # TODO: to be thread safe this would need a lock
         self.last_ingestion_time = int(unix_time_millis())
@@ -166,8 +158,6 @@ class LogStream(BaseModel):
 
     def get_log_events(
         self,
-        log_group_name,
-        log_stream_name,
         start_time,
         end_time,
         limit,
@@ -244,17 +234,7 @@ class LogStream(BaseModel):
             "f/{:056d}".format(end_index),
         )
 
-    def filter_log_events(
-        self,
-        log_group_name,
-        log_stream_names,
-        start_time,
-        end_time,
-        limit,
-        next_token,
-        filter_pattern,
-        interleaved,
-    ):
+    def filter_log_events(self, start_time, end_time, filter_pattern):
         if filter_pattern:
             raise NotImplementedError("filter_pattern is not yet implemented")
 
@@ -281,7 +261,7 @@ class LogGroup(CloudFormationModel):
     def __init__(self, region, name, tags, **kwargs):
         self.name = name
         self.region = region
-        self.arn = f"arn:aws:logs:{region}:{moto_core.ACCOUNT_ID}:log-group:{name}"
+        self.arn = f"arn:aws:logs:{region}:{ACCOUNT_ID}:log-group:{name}"
         self.creation_time = int(unix_time_millis())
         self.tags = tags
         self.streams = dict()  # {name: LogStream}
@@ -317,9 +297,13 @@ class LogGroup(CloudFormationModel):
     def create_log_stream(self, log_stream_name):
         if log_stream_name in self.streams:
             raise ResourceAlreadyExistsException()
-        self.streams[log_stream_name] = LogStream(
-            self.region, self.name, log_stream_name
-        )
+        stream = LogStream(self.region, self.name, log_stream_name)
+        filters = self.describe_subscription_filters()
+
+        if filters:
+            stream.destination_arn = filters[0]["destinationArn"]
+            stream.filter_name = filters[0]["filterName"]
+        self.streams[log_stream_name] = stream
 
     def delete_log_stream(self, log_stream_name):
         if log_stream_name not in self.streams:
@@ -381,19 +365,14 @@ class LogGroup(CloudFormationModel):
 
         return log_streams_page, new_token
 
-    def put_log_events(
-        self, log_group_name, log_stream_name, log_events, sequence_token
-    ):
+    def put_log_events(self, log_group_name, log_stream_name, log_events):
         if log_stream_name not in self.streams:
             raise ResourceNotFoundException("The specified log stream does not exist.")
         stream = self.streams[log_stream_name]
-        return stream.put_log_events(
-            log_group_name, log_stream_name, log_events, sequence_token
-        )
+        return stream.put_log_events(log_group_name, log_stream_name, log_events)
 
     def get_log_events(
         self,
-        log_group_name,
         log_stream_name,
         start_time,
         end_time,
@@ -405,8 +384,6 @@ class LogGroup(CloudFormationModel):
             raise ResourceNotFoundException()
         stream = self.streams[log_stream_name]
         return stream.get_log_events(
-            log_group_name,
-            log_stream_name,
             start_time,
             end_time,
             limit,
@@ -435,16 +412,7 @@ class LogGroup(CloudFormationModel):
 
         events = []
         for stream in streams:
-            events += stream.filter_log_events(
-                log_group_name,
-                log_stream_names,
-                start_time,
-                end_time,
-                limit,
-                next_token,
-                filter_pattern,
-                interleaved,
-            )
+            events += stream.filter_log_events(start_time, end_time, filter_pattern)
 
         if interleaved:
             events = sorted(events, key=lambda event: event["timestamp"])
@@ -734,10 +702,10 @@ class LogsBackend(BaseBackend):
             order_by=order_by,
         )
 
-    def put_log_events(
-        self, log_group_name, log_stream_name, log_events, sequence_token
-    ):
-        # TODO: add support for sequence_tokens
+    def put_log_events(self, log_group_name, log_stream_name, log_events):
+        """
+        The SequenceToken-parameter is not yet implemented
+        """
         if log_group_name not in self.groups:
             raise ResourceNotFoundException()
         log_group = self.groups[log_group_name]
@@ -762,7 +730,7 @@ class LogsBackend(BaseBackend):
             last_timestamp = event["timestamp"]
 
         token = log_group.put_log_events(
-            log_group_name, log_stream_name, allowed_events, sequence_token
+            log_group_name, log_stream_name, allowed_events
         )
         return token, rejected_info
 
@@ -786,13 +754,7 @@ class LogsBackend(BaseBackend):
             )
         log_group = self.groups[log_group_name]
         return log_group.get_log_events(
-            log_group_name,
-            log_stream_name,
-            start_time,
-            end_time,
-            limit,
-            next_token,
-            start_from_head,
+            log_stream_name, start_time, end_time, limit, next_token, start_from_head
         )
 
     def filter_log_events(
@@ -930,11 +892,10 @@ class LogsBackend(BaseBackend):
                 lambda_backends,
             )
 
-            lambda_func = lambda_backends[self.region_name].get_function(
-                destination_arn
-            )
+            try:
+                lambda_backends[self.region_name].get_function(destination_arn)
             # no specific permission check implemented
-            if not lambda_func:
+            except Exception:
                 raise InvalidParameterException(
                     "Could not execute the lambda function. Make sure you "
                     "have given CloudWatch Logs permission to execute your "
@@ -983,17 +944,7 @@ class LogsBackend(BaseBackend):
         self.queries[query_id] = LogQuery(query_id, start_time, end_time, query_string)
         return query_id
 
-    def create_export_task(
-        self,
-        *,
-        task_name,
-        log_group_name,
-        log_stream_name_prefix,
-        fromTime,
-        to,
-        destination,
-        destination_prefix,
-    ):
+    def create_export_task(self, log_group_name, destination):
         s3_backend.get_bucket(destination)
         if log_group_name not in self.groups:
             raise ResourceNotFoundException()
