@@ -8,4 +8,4 @@ class MediaPackageClientError(JsonRESTError):
 # AWS service exceptions are caught with the underlying botocore exception, ClientError
 class ClientError(MediaPackageClientError):
     def __init__(self, error, message):
-        super(ClientError, self).__init__(error, message)
+        super().__init__(error, message)
