@@ -20,6 +20,8 @@ from moto.organizations.exceptions import (
     PolicyTypeNotEnabledException,
     TargetNotFoundException,
 )
+from moto.utilities.paginator import paginate
+from .utils import PAGINATION_MODEL
 
 
 class FakeOrganization(BaseModel):
@@ -104,6 +106,11 @@ class FakeAccount(BaseModel):
             "JoinedTimestamp": unix_time(self.create_time),
         }
 
+    def close(self):
+        # TODO: The CloseAccount spec allows the account to pass through a
+        # "PENDING_CLOSURE" state before reaching the SUSPNEDED state.
+        self.status = "SUSPENDED"
+
 
 class FakeOrganizationalUnit(BaseModel):
     def __init__(self, organization, **kwargs):
@@ -379,7 +386,7 @@ class OrganizationsBackend(BaseBackend):
             raise AWSOrganizationsNotInUseException
         return self.org.describe()
 
-    def delete_organization(self, **kwargs):
+    def delete_organization(self):
         if [account for account in self.accounts if account.name != "master"]:
             raise RESTError(
                 "OrganizationNotEmptyException",
@@ -443,6 +450,13 @@ class OrganizationsBackend(BaseBackend):
         self.attach_policy(PolicyId=utils.DEFAULT_POLICY_ID, TargetId=new_account.id)
         return new_account.create_account_status
 
+    def close_account(self, **kwargs):
+        for account in self.accounts:
+            if account.id == kwargs["AccountId"]:
+                account.close()
+                return
+        raise AccountNotFoundException
+
     def get_account_by_id(self, account_id):
         account = next(
             (account for account in self.accounts if account.id == account_id), None
@@ -495,8 +509,11 @@ class OrganizationsBackend(BaseBackend):
             next_token = str(len(accounts_resp))
         return dict(CreateAccountStatuses=accounts_resp, NextToken=next_token)
 
+    @paginate(pagination_model=PAGINATION_MODEL)
     def list_accounts(self):
-        return dict(Accounts=[account.describe() for account in self.accounts])
+        accounts = [account.describe() for account in self.accounts]
+        accounts = sorted(accounts, key=lambda x: x["JoinedTimestamp"])
+        return accounts
 
     def list_accounts_for_parent(self, **kwargs):
         parent_id = self.validate_parent_id(kwargs["ParentId"])
@@ -612,7 +629,7 @@ class OrganizationsBackend(BaseBackend):
         else:
             raise InvalidInputException("You specified an invalid value.")
 
-    def list_policies(self, **kwargs):
+    def list_policies(self):
         return dict(
             Policies=[p.describe()["Policy"]["PolicySummary"] for p in self.policies]
         )
@@ -822,7 +839,7 @@ class OrganizationsBackend(BaseBackend):
             )
 
         admin = next(
-            (admin for admin in self.admins if admin.account.id == account_id), None,
+            (admin for admin in self.admins if admin.account.id == account_id), None
         )
         if admin is None:
             account = next(
@@ -878,7 +895,7 @@ class OrganizationsBackend(BaseBackend):
                 )
         elif re.match(account_id_regex, target_id):
             account = next(
-                (account for account in self.accounts if account.id == target_id), None,
+                (account for account in self.accounts if account.id == target_id), None
             )
             if account is not None:
                 if policy in account.attached_policies:
