@@ -16,8 +16,8 @@ class OrganizationsResponse(BaseResponse):
         except ValueError:
             return {}
 
-    def _get_param(self, param, default=None):
-        return self.request_params.get(param, default)
+    def _get_param(self, param_name, if_none=None):
+        return self.request_params.get(param_name, if_none)
 
     def create_organization(self):
         return json.dumps(
@@ -28,9 +28,7 @@ class OrganizationsResponse(BaseResponse):
         return json.dumps(self.organizations_backend.describe_organization())
 
     def delete_organization(self):
-        return json.dumps(
-            self.organizations_backend.delete_organization(**self.request_params)
-        )
+        return json.dumps(self.organizations_backend.delete_organization())
 
     def list_roots(self):
         return json.dumps(self.organizations_backend.list_roots())
@@ -69,6 +67,11 @@ class OrganizationsResponse(BaseResponse):
             self.organizations_backend.create_account(**self.request_params)
         )
 
+    def close_account(self):
+        return json.dumps(
+            self.organizations_backend.close_account(**self.request_params)
+        )
+
     def describe_account(self):
         return json.dumps(
             self.organizations_backend.describe_account(**self.request_params)
@@ -87,7 +90,15 @@ class OrganizationsResponse(BaseResponse):
         )
 
     def list_accounts(self):
-        return json.dumps(self.organizations_backend.list_accounts())
+        max_results = self._get_int_param("MaxResults")
+        next_token = self._get_param("NextToken")
+        accounts, next_token = self.organizations_backend.list_accounts(
+            max_results=max_results, next_token=next_token
+        )
+        response = {"Accounts": accounts}
+        if next_token:
+            response["NextToken"] = next_token
+        return json.dumps(response)
 
     def list_accounts_for_parent(self):
         return json.dumps(
@@ -125,9 +136,7 @@ class OrganizationsResponse(BaseResponse):
         )
 
     def list_policies(self):
-        return json.dumps(
-            self.organizations_backend.list_policies(**self.request_params)
-        )
+        return json.dumps(self.organizations_backend.list_policies())
 
     def delete_policy(self):
         self.organizations_backend.delete_policy(**self.request_params)
