@@ -11,7 +11,7 @@ from moto.elb import elb_backends
 from moto.elbv2 import elbv2_backends
 from moto.kinesis import kinesis_backends
 from moto.kms import kms_backends
-from moto.rds2 import rds2_backends
+from moto.rds import rds_backends
 from moto.glacier import glacier_backends
 from moto.redshift import redshift_backends
 from moto.emr import emr_backends
@@ -24,7 +24,7 @@ from moto.awslambda import lambda_backends
 
 class ResourceGroupsTaggingAPIBackend(BaseBackend):
     def __init__(self, region_name=None):
-        super(ResourceGroupsTaggingAPIBackend, self).__init__()
+        super().__init__()
         self.region_name = region_name
 
         self._pages = {}
@@ -83,9 +83,9 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
     @property
     def rds_backend(self):
         """
-        :rtype: moto.rds2.models.RDS2Backend
+        :rtype: moto.rds.models.RDSBackend
         """
-        return rds2_backends[self.region_name]
+        return rds_backends[self.region_name]
 
     @property
     def glacier_backend(self):
@@ -297,40 +297,30 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
 
         # TODO add these to the keys and values functions / combine functions
         # ELB, resource type elasticloadbalancing:loadbalancer
-        def get_elbv2_tags(arn):
-            result = []
-            for key, value in self.elbv2_backend.load_balancers[elb.arn].tags.items():
-                result.append({"Key": key, "Value": value})
-            return result
-
         if (
             not resource_type_filters
             or "elasticloadbalancing" in resource_type_filters
             or "elasticloadbalancing:loadbalancer" in resource_type_filters
         ):
             for elb in self.elbv2_backend.load_balancers.values():
-                tags = get_elbv2_tags(elb.arn)
+                tags = self.elbv2_backend.tagging_service.list_tags_for_resource(
+                    elb.arn
+                )["Tags"]
                 if not tag_filter(tags):  # Skip if no tags, or invalid filter
                     continue
 
                 yield {"ResourceARN": "{0}".format(elb.arn), "Tags": tags}
 
         # ELB Target Group, resource type elasticloadbalancing:targetgroup
-        def get_target_group_tags(arn):
-            result = []
-            for key, value in self.elbv2_backend.target_groups[
-                target_group.arn
-            ].tags.items():
-                result.append({"Key": key, "Value": value})
-            return result
-
         if (
             not resource_type_filters
             or "elasticloadbalancing" in resource_type_filters
             or "elasticloadbalancing:targetgroup" in resource_type_filters
         ):
             for target_group in self.elbv2_backend.target_groups.values():
-                tags = get_target_group_tags(target_group.arn)
+                tags = self.elbv2_backend.tagging_service.list_tags_for_resource(
+                    target_group.arn
+                )["Tags"]
                 if not tag_filter(tags):  # Skip if no tags, or invalid filter
                     continue
 
@@ -383,7 +373,22 @@ class ResourceGroupsTaggingAPIBackend(BaseBackend):
             or "rds" in resource_type_filters
             or "rds:snapshot" in resource_type_filters
         ):
-            for snapshot in self.rds_backend.snapshots.values():
+            for snapshot in self.rds_backend.database_snapshots.values():
+                tags = snapshot.get_tags()
+                if not tags or not tag_filter(tags):
+                    continue
+                yield {
+                    "ResourceARN": snapshot.snapshot_arn,
+                    "Tags": tags,
+                }
+
+        # RDS Cluster Snapshot
+        if (
+            not resource_type_filters
+            or "rds" in resource_type_filters
+            or "rds:cluster-snapshot" in resource_type_filters
+        ):
+            for snapshot in self.rds_backend.cluster_snapshots.values():
                 tags = snapshot.get_tags()
                 if not tags or not tag_filter(tags):
                     continue
