@@ -1,29 +1,18 @@
 import json
 import xmltodict
 
-from functools import wraps
 from moto.core.responses import BaseResponse
 from moto.core.utils import amzn_request_id
 from moto.s3.exceptions import S3ClientError
 from moto.s3.responses import S3_PUBLIC_ACCESS_BLOCK_CONFIGURATION
-from .exceptions import S3ControlError
 from .models import s3control_backend
 
 
-def error_handler(f):
-    @wraps(f)
-    def _wrapper(*args, **kwargs):
-        try:
-            return f(*args, **kwargs)
-        except S3ControlError as e:
-            return e.code, e.get_headers(), e.get_body()
-
-    return _wrapper
-
-
 class S3ControlResponse(BaseResponse):
     @amzn_request_id
-    def public_access_block(self, request, full_url, headers):
+    def public_access_block(
+        self, request, full_url, headers
+    ):  # pylint: disable=unused-argument
         try:
             if request.method == "GET":
                 return self.get_public_access_block(request)
@@ -37,7 +26,7 @@ class S3ControlResponse(BaseResponse):
     def get_public_access_block(self, request):
         account_id = request.headers.get("x-amz-account-id")
         public_block_config = s3control_backend.get_public_access_block(
-            account_id=account_id,
+            account_id=account_id
         )
         template = self.response_template(S3_PUBLIC_ACCESS_BLOCK_CONFIGURATION)
         return 200, {}, template.render(public_block_config=public_block_config)
@@ -53,7 +42,7 @@ class S3ControlResponse(BaseResponse):
 
     def delete_public_access_block(self, request):
         account_id = request.headers.get("x-amz-account-id")
-        s3control_backend.delete_public_access_block(account_id=account_id,)
+        s3control_backend.delete_public_access_block(account_id=account_id)
         return 204, {}, json.dumps({})
 
     def _parse_pab_config(self, body):
@@ -62,7 +51,6 @@ class S3ControlResponse(BaseResponse):
 
         return parsed_xml
 
-    @error_handler
     def access_point(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
         if request.method == "PUT":
@@ -72,7 +60,6 @@ class S3ControlResponse(BaseResponse):
         if request.method == "DELETE":
             return self.delete_access_point(full_url)
 
-    @error_handler
     def access_point_policy(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
         if request.method == "PUT":
@@ -82,7 +69,6 @@ class S3ControlResponse(BaseResponse):
         if request.method == "DELETE":
             return self.delete_access_point_policy(full_url)
 
-    @error_handler
     def access_point_policy_status(self, request, full_url, headers):
         self.setup_class(request, full_url, headers)
         if request.method == "PUT":
@@ -110,16 +96,14 @@ class S3ControlResponse(BaseResponse):
         account_id, name = self._get_accountid_and_name_from_accesspoint(full_url)
 
         access_point = s3control_backend.get_access_point(
-            account_id=account_id, name=name,
+            account_id=account_id, name=name
         )
         template = self.response_template(GET_ACCESS_POINT_TEMPLATE)
         return 200, {}, template.render(access_point=access_point)
 
     def delete_access_point(self, full_url):
         account_id, name = self._get_accountid_and_name_from_accesspoint(full_url)
-        s3control_backend.delete_access_point(
-            account_id=account_id, name=name,
-        )
+        s3control_backend.delete_access_point(account_id=account_id, name=name)
         return 204, {}, ""
 
     def create_access_point_policy(self, full_url):
@@ -137,9 +121,7 @@ class S3ControlResponse(BaseResponse):
 
     def delete_access_point_policy(self, full_url):
         account_id, name = self._get_accountid_and_name_from_policy(full_url)
-        s3control_backend.delete_access_point_policy(
-            account_id=account_id, name=name,
-        )
+        s3control_backend.delete_access_point_policy(account_id=account_id, name=name)
         return 204, {}, ""
 
     def get_access_point_policy_status(self, full_url):
