@@ -45,7 +45,7 @@ def _matches(secret, filters):
 
 
 class SecretsManager(BaseModel):
-    def __init__(self, region_name, **kwargs):
+    def __init__(self, region_name):
         self.region = region_name
 
 
@@ -180,13 +180,17 @@ class SecretsStore(dict):
         new_key = get_secret_name_from_arn(key)
         return dict.__contains__(self, new_key)
 
+    def get(self, key, *args, **kwargs):
+        new_key = get_secret_name_from_arn(key)
+        return super().get(new_key, *args, **kwargs)
+
     def pop(self, key, *args, **kwargs):
         new_key = get_secret_name_from_arn(key)
         return super().pop(new_key, *args, **kwargs)
 
 
 class SecretsManagerBackend(BaseBackend):
-    def __init__(self, region_name=None, **kwargs):
+    def __init__(self, region_name=None):
         super().__init__()
         self.region = region_name
         self.secrets = SecretsStore()
@@ -288,7 +292,6 @@ class SecretsManagerBackend(BaseBackend):
         secret_binary=None,
         client_request_token=None,
         kms_key_id=None,
-        **kwargs
     ):
 
         # error if secret does not exist
@@ -534,8 +537,9 @@ class SecretsManagerBackend(BaseBackend):
             request_headers = {}
             response_headers = {}
 
-            func = lambda_backend.get_function(secret.rotation_lambda_arn)
-            if not func:
+            try:
+                func = lambda_backend.get_function(secret.rotation_lambda_arn)
+            except Exception:
                 msg = "Resource not found for ARN '{}'.".format(
                     secret.rotation_lambda_arn
                 )
