@@ -77,8 +77,8 @@ class Topic(CloudFormationModel):
         return message_id
 
     @classmethod
-    def has_cfn_attr(cls, attribute):
-        return attribute in ["TopicName"]
+    def has_cfn_attr(cls, attr):
+        return attr in ["TopicName"]
 
     def get_cfn_attribute(self, attribute_name):
         from moto.cloudformation.exceptions import UnformattedGetAttTemplateException
@@ -389,12 +389,14 @@ class PlatformEndpoint(BaseModel):
 
     @property
     def arn(self):
-        return "arn:aws:sns:{region}:{AccountId}:endpoint/{platform}/{name}/{id}".format(
-            region=self.region,
-            AccountId=DEFAULT_ACCOUNT_ID,
-            platform=self.application.platform,
-            name=self.application.name,
-            id=self.id,
+        return (
+            "arn:aws:sns:{region}:{AccountId}:endpoint/{platform}/{name}/{id}".format(
+                region=self.region,
+                AccountId=DEFAULT_ACCOUNT_ID,
+                platform=self.application.platform,
+                name=self.application.name,
+                id=self.id,
+            )
         )
 
     def publish(self, message):
