@@ -5,7 +5,7 @@ class ReceiptHandleIsInvalid(RESTError):
     code = 400
 
     def __init__(self):
-        super(ReceiptHandleIsInvalid, self).__init__(
+        super().__init__(
             "ReceiptHandleIsInvalid", "The input receipt handle is invalid."
         )
 
@@ -14,9 +14,7 @@ class MessageAttributesInvalid(RESTError):
     code = 400
 
     def __init__(self, description):
-        super(MessageAttributesInvalid, self).__init__(
-            "MessageAttributesInvalid", description
-        )
+        super().__init__("MessageAttributesInvalid", description)
 
 
 class QueueDoesNotExist(RESTError):
@@ -34,14 +32,14 @@ class QueueAlreadyExists(RESTError):
     code = 400
 
     def __init__(self, message):
-        super(QueueAlreadyExists, self).__init__("QueueAlreadyExists", message)
+        super().__init__("QueueAlreadyExists", message)
 
 
 class EmptyBatchRequest(RESTError):
     code = 400
 
     def __init__(self):
-        super(EmptyBatchRequest, self).__init__(
+        super().__init__(
             "EmptyBatchRequest",
             "There should be at least one SendMessageBatchRequestEntry in the request.",
         )
@@ -51,7 +49,7 @@ class InvalidBatchEntryId(RESTError):
     code = 400
 
     def __init__(self):
-        super(InvalidBatchEntryId, self).__init__(
+        super().__init__(
             "InvalidBatchEntryId",
             "A batch entry id can only contain alphanumeric characters, "
             "hyphens and underscores. It can be at most 80 letters long.",
@@ -62,7 +60,7 @@ class BatchRequestTooLong(RESTError):
     code = 400
 
     def __init__(self, length):
-        super(BatchRequestTooLong, self).__init__(
+        super().__init__(
             "BatchRequestTooLong",
             "Batch requests cannot be longer than 262144 bytes. "
             "You have sent {} bytes.".format(length),
@@ -73,16 +71,14 @@ class BatchEntryIdsNotDistinct(RESTError):
     code = 400
 
     def __init__(self, entry_id):
-        super(BatchEntryIdsNotDistinct, self).__init__(
-            "BatchEntryIdsNotDistinct", "Id {} repeated.".format(entry_id)
-        )
+        super().__init__("BatchEntryIdsNotDistinct", "Id {} repeated.".format(entry_id))
 
 
 class TooManyEntriesInBatchRequest(RESTError):
     code = 400
 
     def __init__(self, number):
-        super(TooManyEntriesInBatchRequest, self).__init__(
+        super().__init__(
             "TooManyEntriesInBatchRequest",
             "Maximum number of entries per request are 10. "
             "You have sent {}.".format(number),
@@ -93,7 +89,7 @@ class InvalidAttributeName(RESTError):
     code = 400
 
     def __init__(self, attribute_name):
-        super(InvalidAttributeName, self).__init__(
+        super().__init__(
             "InvalidAttributeName", "Unknown Attribute {}.".format(attribute_name)
         )
 
@@ -102,7 +98,7 @@ class InvalidAttributeValue(RESTError):
     code = 400
 
     def __init__(self, attribute_name):
-        super(InvalidAttributeValue, self).__init__(
+        super().__init__(
             "InvalidAttributeValue",
             "Invalid value for the parameter {}.".format(attribute_name),
         )
@@ -112,14 +108,14 @@ class InvalidParameterValue(RESTError):
     code = 400
 
     def __init__(self, message):
-        super(InvalidParameterValue, self).__init__("InvalidParameterValue", message)
+        super().__init__("InvalidParameterValue", message)
 
 
 class MissingParameter(RESTError):
     code = 400
 
     def __init__(self, parameter):
-        super(MissingParameter, self).__init__(
+        super().__init__(
             "MissingParameter",
             "The request must contain the parameter {}.".format(parameter),
         )
@@ -129,16 +125,6 @@ class OverLimit(RESTError):
     code = 403
 
     def __init__(self, count):
-        super(OverLimit, self).__init__(
+        super().__init__(
             "OverLimit", "{} Actions were found, maximum allowed is 7.".format(count)
         )
-
-
-class InvalidAddress(RESTError):
-    code = 400
-
-    def __init__(self, address):
-        super(InvalidAddress, self).__init__(
-            "InvalidAddress",
-            "The address {} is not valid for this endpoint.".format(address),
-        )
