@@ -24,6 +24,14 @@ SUPPORTED_HISTORY_EVENT_TYPES = (
     "DecisionTaskTimedOut",
     "WorkflowExecutionTimedOut",
     "WorkflowExecutionSignaled",
+    "MarkerRecorded",
+    "TimerStarted",
+    "TimerCancelled",
+    "TimerFired",
+    "CancelTimerFailed",
+    "StartTimerFailed",
+    "WorkflowExecutionCanceled",
+    "CancelWorkflowExecutionFailed",
 )
 
 
